@@ -1,4 +1,4 @@
-/* -*- mode: C++ ; c-file-style: "stroustrup" -*- *****************************
+/******************************************************************************
  * Qwt Widget Library
  * Copyright (C) 1997   Josef Wilgen
  * Copyright (C) 2002   Uwe Rathmann
@@ -10,19 +10,17 @@
 #include "qwt_dial.h"
 #include "qwt_dial_needle.h"
 #include "qwt_math.h"
-#include "qwt_scale_engine.h"
 #include "qwt_scale_map.h"
 #include "qwt_round_scale_draw.h"
 #include "qwt_painter.h"
+#include "qwt.h"
+
 #include <qpainter.h>
 #include <qpalette.h>
 #include <qpixmap.h>
 #include <qevent.h>
-#include <qalgorithms.h>
-#include <qmath.h>
 #include <qstyle.h>
 #include <qstyleoption.h>
-#include <qapplication.h>
 
 static inline double qwtAngleDist( double a1, double a2 )
 {
@@ -76,17 +74,17 @@ static inline double qwtBoundedAngle( double min, double angle, double max )
 
 class QwtDial::PrivateData
 {
-public:
-    PrivateData():
-        frameShadow( Sunken ),
-        lineWidth( 0 ),
-        mode( RotateNeedle ),
-        origin( 90.0 ),
-        minScaleArc( 0.0 ),
-        maxScaleArc( 0.0 ),
-        needle( NULL ),
-        arcOffset( 0.0 ),
-        mouseOffset( 0.0 )
+  public:
+    PrivateData()
+        : frameShadow( Sunken )
+        , lineWidth( 0 )
+        , mode( RotateNeedle )
+        , origin( 90.0 )
+        , minScaleArc( 0.0 )
+        , maxScaleArc( 0.0 )
+        , needle( NULL )
+        , arcOffset( 0.0 )
+        , mouseOffset( 0.0 )
     {
     }
 
@@ -103,7 +101,7 @@ public:
     double minScaleArc;
     double maxScaleArc;
 
-    QwtDialNeedle *needle;
+    QwtDialNeedle* needle;
 
     double arcOffset;
     double mouseOffset;
@@ -112,21 +110,21 @@ public:
 };
 
 /*!
-  \brief Constructor
-  \param parent Parent widget
+   \brief Constructor
+   \param parent Parent widget
 
-  Create a dial widget with no needle. The scale is initialized
-  to [ 0.0, 360.0 ] and 360 steps ( QwtAbstractSlider::setTotalSteps() ).
-  The origin of the scale is at 90°,
+   Create a dial widget with no needle. The scale is initialized
+   to [ 0.0, 360.0 ] and 360 steps ( QwtAbstractSlider::setTotalSteps() ).
+   The origin of the scale is at 90°,
 
-  The value is set to 0.0.
+   The value is set to 0.0.
 
-  The default mode is QwtDial::RotateNeedle.
-*/
-QwtDial::QwtDial( QWidget* parent ):
-    QwtAbstractSlider( parent )
+   The default mode is QwtDial::RotateNeedle.
+ */
+QwtDial::QwtDial( QWidget* parent )
+    : QwtAbstractSlider( parent )
 {
-    d_data = new PrivateData;
+    m_data = new PrivateData;
 
     setFocusPolicy( Qt::TabFocus );
 
@@ -134,7 +132,7 @@ QwtDial::QwtDial( QWidget* parent ):
     for ( int i = 0; i < QPalette::NColorGroups; i++ )
     {
         const QPalette::ColorGroup colorGroup =
-            static_cast<QPalette::ColorGroup>( i );
+            static_cast< QPalette::ColorGroup >( i );
 
         // Base: background color of the circle inside the frame.
         // WindowText: background color of the circle inside the scale
@@ -160,69 +158,69 @@ QwtDial::QwtDial( QWidget* parent ):
 //!  Destructor
 QwtDial::~QwtDial()
 {
-    delete d_data;
+    delete m_data;
 }
 
 /*!
-  Sets the frame shadow value from the frame style.
+   Sets the frame shadow value from the frame style.
 
-  \param shadow Frame shadow
-  \sa setLineWidth(), QFrame::setFrameShadow()
-*/
+   \param shadow Frame shadow
+   \sa setLineWidth(), QFrame::setFrameShadow()
+ */
 void QwtDial::setFrameShadow( Shadow shadow )
 {
-    if ( shadow != d_data->frameShadow )
+    if ( shadow != m_data->frameShadow )
     {
         invalidateCache();
 
-        d_data->frameShadow = shadow;
+        m_data->frameShadow = shadow;
         if ( lineWidth() > 0 )
             update();
     }
 }
 
 /*!
-  \return Frame shadow
-  /sa setFrameShadow(), lineWidth(), QFrame::frameShadow()
-*/
+   \return Frame shadow
+   /sa setFrameShadow(), lineWidth(), QFrame::frameShadow()
+ */
 QwtDial::Shadow QwtDial::frameShadow() const
 {
-    return d_data->frameShadow;
+    return m_data->frameShadow;
 }
 
 /*!
-  Sets the line width of the frame
+   Sets the line width of the frame
 
-  \param lineWidth Line width
-  \sa setFrameShadow()
-*/
+   \param lineWidth Line width
+   \sa setFrameShadow()
+ */
 void QwtDial::setLineWidth( int lineWidth )
 {
     if ( lineWidth < 0 )
         lineWidth = 0;
 
-    if ( d_data->lineWidth != lineWidth )
+    if ( m_data->lineWidth != lineWidth )
     {
         invalidateCache();
 
-        d_data->lineWidth = lineWidth;
+        m_data->lineWidth = lineWidth;
         update();
     }
 }
 
 /*!
-  \return Line width of the frame
-  \sa setLineWidth(), frameShadow(), lineWidth()
-*/
+   \return Line width of the frame
+   \sa setLineWidth(), frameShadow(), lineWidth()
+ */
 int QwtDial::lineWidth() const
 {
-    return d_data->lineWidth;
+    return m_data->lineWidth;
 }
 
 /*!
-  \return bounding rectangle of the circle inside the frame
-  \sa setLineWidth(), scaleInnerRect(), boundingRect()
-*/
+   \return bounding rectangle of the circle inside the frame
+   \sa setLineWidth(), scaleInnerRect(), boundingRect()
+ */
 QRect QwtDial::innerRect() const
 {
     const int lw = lineWidth();
@@ -230,9 +228,9 @@ QRect QwtDial::innerRect() const
 }
 
 /*!
-  \return bounding rectangle of the dial including the frame
-  \sa setLineWidth(), scaleInnerRect(), innerRect()
-*/
+   \return bounding rectangle of the dial including the frame
+   \sa setLineWidth(), scaleInnerRect(), innerRect()
+ */
 QRect QwtDial::boundingRect() const
 {
     const QRect cr = contentsRect();
@@ -246,17 +244,17 @@ QRect QwtDial::boundingRect() const
 }
 
 /*!
-  \return rectangle inside the scale
-  \sa setLineWidth(), boundingRect(), innerRect()
-*/
+   \return rectangle inside the scale
+   \sa setLineWidth(), boundingRect(), innerRect()
+ */
 QRect QwtDial::scaleInnerRect() const
 {
     QRect rect = innerRect();
 
-    const QwtAbstractScaleDraw *sd = scaleDraw();
+    const QwtAbstractScaleDraw* sd = scaleDraw();
     if ( sd )
     {
-        int scaleDist = qCeil( sd->extent( font() ) );
+        int scaleDist = qwtCeil( sd->extent( font() ) );
         scaleDist++; // margin
 
         rect.adjust( scaleDist, scaleDist, -scaleDist, -scaleDist );
@@ -266,59 +264,59 @@ QRect QwtDial::scaleInnerRect() const
 }
 
 /*!
-  \brief Change the mode of the dial.
-  \param mode New mode
+   \brief Change the mode of the dial.
+   \param mode New mode
 
-  In case of QwtDial::RotateNeedle the needle is rotating, in case of
-  QwtDial::RotateScale, the needle points to origin()
-  and the scale is rotating.
+   In case of QwtDial::RotateNeedle the needle is rotating, in case of
+   QwtDial::RotateScale, the needle points to origin()
+   and the scale is rotating.
 
-  The default mode is QwtDial::RotateNeedle.
+   The default mode is QwtDial::RotateNeedle.
 
-  \sa mode(), setValue(), setOrigin()
-*/
+   \sa mode(), setValue(), setOrigin()
+ */
 void QwtDial::setMode( Mode mode )
 {
-    if ( mode != d_data->mode )
+    if ( mode != m_data->mode )
     {
         invalidateCache();
 
-        d_data->mode = mode;
+        m_data->mode = mode;
         sliderChange();
     }
 }
 
 /*!
-  \return Mode of the dial.
-  \sa setMode(), origin(), setScaleArc(), value()
-*/
+   \return Mode of the dial.
+   \sa setMode(), origin(), setScaleArc(), value()
+ */
 QwtDial::Mode QwtDial::mode() const
 {
-    return d_data->mode;
+    return m_data->mode;
 }
 
 /*!
-  Invalidate the internal caches used to speed up repainting
+   Invalidate the internal caches used to speed up repainting
  */
 void QwtDial::invalidateCache()
 {
-    d_data->pixmapCache = QPixmap();
+    m_data->pixmapCache = QPixmap();
 }
 
 /*!
    Paint the dial
    \param event Paint event
-*/
-void QwtDial::paintEvent( QPaintEvent *event )
+ */
+void QwtDial::paintEvent( QPaintEvent* event )
 {
     QPainter painter( this );
     painter.setClipRegion( event->region() );
 
     QStyleOption opt;
-    opt.init(this);
+    opt.initFrom(this);
     style()->drawPrimitive(QStyle::PE_Widget, &opt, &painter, this);
 
-    if ( d_data->mode == QwtDial::RotateScale )
+    if ( m_data->mode == QwtDial::RotateScale )
     {
         painter.save();
         painter.setRenderHint( QPainter::Antialiasing, true );
@@ -329,28 +327,28 @@ void QwtDial::paintEvent( QPaintEvent *event )
     }
 
     const QRect r = contentsRect();
-    if ( r.size() != d_data->pixmapCache.size() )
+    if ( r.size() != m_data->pixmapCache.size() )
     {
-        d_data->pixmapCache = QwtPainter::backingStore( this, r.size() );
-        d_data->pixmapCache.fill( Qt::transparent );
+        m_data->pixmapCache = QwtPainter::backingStore( this, r.size() );
+        m_data->pixmapCache.fill( Qt::transparent );
 
-        QPainter p( &d_data->pixmapCache );
+        QPainter p( &m_data->pixmapCache );
         p.setRenderHint( QPainter::Antialiasing, true );
         p.translate( -r.topLeft() );
 
-        if ( d_data->mode != QwtDial::RotateScale )
+        if ( m_data->mode != QwtDial::RotateScale )
             drawContents( &p );
 
         if ( lineWidth() > 0 )
             drawFrame( &p );
 
-        if ( d_data->mode != QwtDial::RotateNeedle )
+        if ( m_data->mode != QwtDial::RotateNeedle )
             drawNeedle( &p );
     }
 
-    painter.drawPixmap( r.topLeft(), d_data->pixmapCache );
+    painter.drawPixmap( r.topLeft(), m_data->pixmapCache );
 
-    if ( d_data->mode == QwtDial::RotateNeedle )
+    if ( m_data->mode == QwtDial::RotateNeedle )
         drawNeedle( &painter );
 
     if ( hasFocus() )
@@ -358,43 +356,43 @@ void QwtDial::paintEvent( QPaintEvent *event )
 }
 
 /*!
-  Draw the focus indicator
-  \param painter Painter
-*/
-void QwtDial::drawFocusIndicator( QPainter *painter ) const
+   Draw the focus indicator
+   \param painter Painter
+ */
+void QwtDial::drawFocusIndicator( QPainter* painter ) const
 {
     QwtPainter::drawFocusRect( painter, this, boundingRect() );
 }
 
 /*!
-  Draw the frame around the dial
+   Draw the frame around the dial
 
-  \param painter Painter
-  \sa lineWidth(), frameShadow()
-*/
-void QwtDial::drawFrame( QPainter *painter )
+   \param painter Painter
+   \sa lineWidth(), frameShadow()
+ */
+void QwtDial::drawFrame( QPainter* painter )
 {
     QwtPainter::drawRoundFrame( painter, boundingRect(),
-        palette(), lineWidth(), d_data->frameShadow );
+        palette(), lineWidth(), m_data->frameShadow );
 }
 
 /*!
-  \brief Draw the contents inside the frame
+   \brief Draw the contents inside the frame
 
-  QPalette::Window is the background color outside of the frame.
-  QPalette::Base is the background color inside the frame.
-  QPalette::WindowText is the background color inside the scale.
+   QPalette::Window is the background color outside of the frame.
+   QPalette::Base is the background color inside the frame.
+   QPalette::WindowText is the background color inside the scale.
 
-  \param painter Painter
+   \param painter Painter
 
-  \sa boundingRect(), innerRect(),
+   \sa boundingRect(), innerRect(),
     scaleInnerRect(), QWidget::setPalette()
-*/
-void QwtDial::drawContents( QPainter *painter ) const
+ */
+void QwtDial::drawContents( QPainter* painter ) const
 {
     if ( testAttribute( Qt::WA_NoSystemBackground ) ||
         palette().brush( QPalette::Base ) !=
-            palette().brush( QPalette::Window ) )
+        palette().brush( QPalette::Window ) )
     {
         const QRectF br = boundingRect();
 
@@ -407,7 +405,7 @@ void QwtDial::drawContents( QPainter *painter ) const
 
     const QRectF insideScaleRect = scaleInnerRect();
     if ( palette().brush( QPalette::WindowText ) !=
-            palette().brush( QPalette::Base ) )
+        palette().brush( QPalette::Base ) )
     {
         painter->save();
         painter->setPen( Qt::NoPen );
@@ -429,25 +427,25 @@ void QwtDial::drawContents( QPainter *painter ) const
 }
 
 /*!
-  Draw the needle
+   Draw the needle
 
-  \param painter Painter
-  \param center Center of the dial
-  \param radius Length for the needle
-  \param direction Direction of the needle in degrees, counter clockwise
-  \param colorGroup ColorGroup
-*/
-void QwtDial::drawNeedle( QPainter *painter, const QPointF &center,
+   \param painter Painter
+   \param center Center of the dial
+   \param radius Length for the needle
+   \param direction Direction of the needle in degrees, counter clockwise
+   \param colorGroup ColorGroup
+ */
+void QwtDial::drawNeedle( QPainter* painter, const QPointF& center,
     double radius, double direction, QPalette::ColorGroup colorGroup ) const
 {
-    if ( d_data->needle )
+    if ( m_data->needle )
     {
         direction = 360.0 - direction; // counter clockwise
-        d_data->needle->draw( painter, center, radius, direction, colorGroup );
+        m_data->needle->draw( painter, center, radius, direction, colorGroup );
     }
 }
 
-void QwtDial::drawNeedle( QPainter *painter ) const
+void QwtDial::drawNeedle( QPainter* painter ) const
 {
     if ( !isValid() )
         return;
@@ -468,16 +466,16 @@ void QwtDial::drawNeedle( QPainter *painter ) const
 }
 
 /*!
-  Draw the scale
+   Draw the scale
 
-  \param painter Painter
-  \param center Center of the dial
-  \param radius Radius of the scale
-*/
-void QwtDial::drawScale( QPainter *painter,
-    const QPointF &center, double radius ) const
+   \param painter Painter
+   \param center Center of the dial
+   \param radius Radius of the scale
+ */
+void QwtDial::drawScale( QPainter* painter,
+    const QPointF& center, double radius ) const
 {
-    QwtRoundScaleDraw *sd = const_cast<QwtRoundScaleDraw *>( scaleDraw() );
+    QwtRoundScaleDraw* sd = const_cast< QwtRoundScaleDraw* >( scaleDraw() );
     if ( sd == NULL )
         return;
 
@@ -490,23 +488,23 @@ void QwtDial::drawScale( QPainter *painter,
     pal.setColor( QPalette::WindowText, textColor ); // ticks, backbone
 
     painter->setFont( font() );
-    painter->setPen( QPen( textColor, sd->penWidth() ) );
+    painter->setPen( QPen( textColor, sd->penWidthF() ) );
 
     painter->setBrush( Qt::red );
     sd->draw( painter, pal );
 }
 
 /*!
-  Draw the contents inside the scale
+   Draw the contents inside the scale
 
-  Paints nothing.
+   Paints nothing.
 
-  \param painter Painter
-  \param center Center of the contents circle
-  \param radius Radius of the contents circle
-*/
-void QwtDial::drawScaleContents( QPainter *painter,
-    const QPointF &center, double radius ) const
+   \param painter Painter
+   \param center Center of the contents circle
+   \param radius Radius of the contents circle
+ */
+void QwtDial::drawScaleContents( QPainter* painter,
+    const QPointF& center, double radius ) const
 {
     Q_UNUSED(painter);
     Q_UNUSED(center);
@@ -514,97 +512,97 @@ void QwtDial::drawScaleContents( QPainter *painter,
 }
 
 /*!
-  Set a needle for the dial
+   Set a needle for the dial
 
-  \param needle Needle
+   \param needle Needle
 
-  \warning The needle will be deleted, when a different needle is
+   \warning The needle will be deleted, when a different needle is
            set or in ~QwtDial()
-*/
-void QwtDial::setNeedle( QwtDialNeedle *needle )
+ */
+void QwtDial::setNeedle( QwtDialNeedle* needle )
 {
-    if ( needle != d_data->needle )
+    if ( needle != m_data->needle )
     {
-        if ( d_data->needle )
-            delete d_data->needle;
+        if ( m_data->needle )
+            delete m_data->needle;
 
-        d_data->needle = needle;
+        m_data->needle = needle;
         update();
     }
 }
 
 /*!
-  \return needle
-  \sa setNeedle()
-*/
-const QwtDialNeedle *QwtDial::needle() const
+   \return needle
+   \sa setNeedle()
+ */
+const QwtDialNeedle* QwtDial::needle() const
 {
-    return d_data->needle;
+    return m_data->needle;
 }
 
 /*!
-  \return needle
-  \sa setNeedle()
-*/
-QwtDialNeedle *QwtDial::needle()
+   \return needle
+   \sa setNeedle()
+ */
+QwtDialNeedle* QwtDial::needle()
 {
-    return d_data->needle;
+    return m_data->needle;
 }
 
 //! \return the scale draw
-QwtRoundScaleDraw *QwtDial::scaleDraw()
+QwtRoundScaleDraw* QwtDial::scaleDraw()
 {
-    return static_cast<QwtRoundScaleDraw *>( abstractScaleDraw() );
+    return static_cast< QwtRoundScaleDraw* >( abstractScaleDraw() );
 }
 
 //! \return the scale draw
-const QwtRoundScaleDraw *QwtDial::scaleDraw() const
+const QwtRoundScaleDraw* QwtDial::scaleDraw() const
 {
-    return static_cast<const QwtRoundScaleDraw *>( abstractScaleDraw() );
+    return static_cast< const QwtRoundScaleDraw* >( abstractScaleDraw() );
 }
 
 /*!
-  Set an individual scale draw
+   Set an individual scale draw
 
-  The motivation for setting a scale draw is often
-  to overload QwtRoundScaleDraw::label() to return
-  individual tick labels.
+   The motivation for setting a scale draw is often
+   to overload QwtRoundScaleDraw::label() to return
+   individual tick labels.
 
-  \param scaleDraw Scale draw
-  \warning The previous scale draw is deleted
-*/
-void QwtDial::setScaleDraw( QwtRoundScaleDraw *scaleDraw )
+   \param scaleDraw Scale draw
+   \warning The previous scale draw is deleted
+ */
+void QwtDial::setScaleDraw( QwtRoundScaleDraw* scaleDraw )
 {
     setAbstractScaleDraw( scaleDraw );
     sliderChange();
 }
 
 /*!
-  Change the arc of the scale
+   Change the arc of the scale
 
-  \param minArc Lower limit
-  \param maxArc Upper limit
+   \param minArc Lower limit
+   \param maxArc Upper limit
 
-  \sa minScaleArc(), maxScaleArc()
-*/
+   \sa minScaleArc(), maxScaleArc()
+ */
 void QwtDial::setScaleArc( double minArc, double maxArc )
 {
     if ( minArc != 360.0 && minArc != -360.0 )
-        minArc = ::fmod( minArc, 360.0 );
+        minArc = std::fmod( minArc, 360.0 );
     if ( maxArc != 360.0 && maxArc != -360.0 )
-        maxArc = ::fmod( maxArc, 360.0 );
+        maxArc = std::fmod( maxArc, 360.0 );
 
-    double minScaleArc = qMin( minArc, maxArc );
-    double maxScaleArc = qMax( minArc, maxArc );
+    double minScaleArc = qwtMinF( minArc, maxArc );
+    double maxScaleArc = qwtMaxF( minArc, maxArc );
 
     if ( maxScaleArc - minScaleArc > 360.0 )
         maxScaleArc = minScaleArc + 360.0;
 
-    if ( ( minScaleArc != d_data->minScaleArc ) ||
-        ( maxScaleArc != d_data->maxScaleArc ) )
+    if ( ( minScaleArc != m_data->minScaleArc ) ||
+        ( maxScaleArc != m_data->maxScaleArc ) )
     {
-        d_data->minScaleArc = minScaleArc;
-        d_data->maxScaleArc = maxScaleArc;
+        m_data->minScaleArc = minScaleArc;
+        m_data->maxScaleArc = maxScaleArc;
 
         invalidateCache();
         sliderChange();
@@ -612,100 +610,100 @@ void QwtDial::setScaleArc( double minArc, double maxArc )
 }
 
 /*!
-  Set the lower limit for the scale arc
+   Set the lower limit for the scale arc
 
-  \param min Lower limit of the scale arc
-  \sa setScaleArc(), setMaxScaleArc()
+   \param min Lower limit of the scale arc
+   \sa setScaleArc(), setMaxScaleArc()
  */
 void QwtDial::setMinScaleArc( double min )
 {
-    setScaleArc( min, d_data->maxScaleArc );
+    setScaleArc( min, m_data->maxScaleArc );
 }
 
 /*!
-  \return Lower limit of the scale arc
-  \sa setScaleArc()
-*/
+   \return Lower limit of the scale arc
+   \sa setScaleArc()
+ */
 double QwtDial::minScaleArc() const
 {
-    return d_data->minScaleArc;
+    return m_data->minScaleArc;
 }
 
 /*!
-  Set the upper limit for the scale arc
+   Set the upper limit for the scale arc
 
-  \param max Upper limit of the scale arc
-  \sa setScaleArc(), setMinScaleArc()
+   \param max Upper limit of the scale arc
+   \sa setScaleArc(), setMinScaleArc()
  */
 void QwtDial::setMaxScaleArc( double max )
 {
-    setScaleArc( d_data->minScaleArc, max );
+    setScaleArc( m_data->minScaleArc, max );
 }
 
 /*!
-  \return Upper limit of the scale arc
-  \sa setScaleArc()
-*/
+   \return Upper limit of the scale arc
+   \sa setScaleArc()
+ */
 double QwtDial::maxScaleArc() const
 {
-    return d_data->maxScaleArc;
+    return m_data->maxScaleArc;
 }
 
 /*!
-  \brief Change the origin
+   \brief Change the origin
 
-  The origin is the angle where scale and needle is relative to.
+   The origin is the angle where scale and needle is relative to.
 
-  \param origin New origin
-  \sa origin()
-*/
+   \param origin New origin
+   \sa origin()
+ */
 void QwtDial::setOrigin( double origin )
 {
     invalidateCache();
 
-    d_data->origin = origin;
+    m_data->origin = origin;
     sliderChange();
 }
 
 /*!
-  The origin is the angle where scale and needle is relative to.
+   The origin is the angle where scale and needle is relative to.
 
-  \return Origin of the dial
-  \sa setOrigin()
-*/
+   \return Origin of the dial
+   \sa setOrigin()
+ */
 double QwtDial::origin() const
 {
-    return d_data->origin;
+    return m_data->origin;
 }
 
 /*!
-  \return Size hint
-  \sa minimumSizeHint()
-*/
+   \return Size hint
+   \sa minimumSizeHint()
+ */
 QSize QwtDial::sizeHint() const
 {
     int sh = 0;
     if ( scaleDraw() )
-        sh = qCeil( scaleDraw()->extent( font() ) );
+        sh = qwtCeil( scaleDraw()->extent( font() ) );
 
     const int d = 6 * sh + 2 * lineWidth();
 
     QSize hint( d, d );
     if ( !isReadOnly() )
-        hint = hint.expandedTo( QApplication::globalStrut() );
+        hint = qwtExpandedToGlobalStrut( hint );
 
     return hint;
 }
 
 /*!
-  \return Minimum size hint
-  \sa sizeHint()
-*/
+   \return Minimum size hint
+   \sa sizeHint()
+ */
 QSize QwtDial::minimumSizeHint() const
 {
     int sh = 0;
     if ( scaleDraw() )
-        sh = qCeil( scaleDraw()->extent( font() ) );
+        sh = qwtCeil( scaleDraw()->extent( font() ) );
 
     const int d = 3 * sh + 2 * lineWidth();
 
@@ -713,27 +711,27 @@ QSize QwtDial::minimumSizeHint() const
 }
 
 /*!
-  \brief Determine what to do when the user presses a mouse button.
+   \brief Determine what to do when the user presses a mouse button.
 
-  \param pos Mouse position
+   \param pos Mouse position
 
-  \retval True, when the inner circle contains pos
-  \sa scrolledTo()
-*/
-bool QwtDial::isScrollPosition( const QPoint &pos ) const
+   \retval True, when the inner circle contains pos
+   \sa scrolledTo()
+ */
+bool QwtDial::isScrollPosition( const QPoint& pos ) const
 {
     const QRegion region( innerRect(), QRegion::Ellipse );
     if ( region.contains( pos ) && ( pos != innerRect().center() ) )
     {
         double angle = QLineF( rect().center(), pos ).angle();
-        if ( d_data->mode == QwtDial::RotateScale )
+        if ( m_data->mode == QwtDial::RotateScale )
             angle = 360.0 - angle;
 
         double valueAngle =
             qwtNormalizeDegrees( 90.0 - scaleMap().transform( value() ) );
 
-        d_data->mouseOffset = qwtNormalizeDegrees( angle - valueAngle );
-        d_data->arcOffset = scaleMap().p1();
+        m_data->mouseOffset = qwtNormalizeDegrees( angle - valueAngle );
+        m_data->arcOffset = scaleMap().p1();
 
         return true;
     }
@@ -742,24 +740,24 @@ bool QwtDial::isScrollPosition( const QPoint &pos ) const
 }
 
 /*!
-  \brief Determine the value for a new position of the
+   \brief Determine the value for a new position of the
          slider handle.
 
-  \param pos Mouse position
+   \param pos Mouse position
 
-  \return Value for the mouse position
-  \sa isScrollPosition()
-*/
-double QwtDial::scrolledTo( const QPoint &pos ) const
+   \return Value for the mouse position
+   \sa isScrollPosition()
+ */
+double QwtDial::scrolledTo( const QPoint& pos ) const
 {
     double angle = QLineF( rect().center(), pos ).angle();
-    if ( d_data->mode == QwtDial::RotateScale )
+    if ( m_data->mode == QwtDial::RotateScale )
     {
-        angle += scaleMap().p1() - d_data->arcOffset;
+        angle += scaleMap().p1() - m_data->arcOffset;
         angle = 360.0 - angle;
     }
 
-    angle = qwtNormalizeDegrees( angle - d_data->mouseOffset );
+    angle = qwtNormalizeDegrees( angle - m_data->mouseOffset );
     angle = qwtNormalizeDegrees( 90.0 - angle );
 
     if ( scaleMap().pDist() >= 360.0 )
@@ -778,7 +776,7 @@ double QwtDial::scrolledTo( const QPoint &pos ) const
                     ? scaleMap().p1() : scaleMap().p2();
             }
 
-            d_data->mouseOffset += ( boundedAngle - angle );
+            m_data->mouseOffset += ( boundedAngle - angle );
 
             angle = boundedAngle;
         }
@@ -789,7 +787,7 @@ double QwtDial::scrolledTo( const QPoint &pos ) const
             qwtBoundedAngle( scaleMap().p1(), angle, scaleMap().p2() );
 
         if ( !wrapping() )
-            d_data->mouseOffset += ( boundedAngle - angle );
+            m_data->mouseOffset += ( boundedAngle - angle );
 
         angle = boundedAngle;
     }
@@ -798,12 +796,12 @@ double QwtDial::scrolledTo( const QPoint &pos ) const
 }
 
 /*!
-  Change Event handler
-  \param event Change event
+   Change Event handler
+   \param event Change event
 
-  Invalidates internal paint caches if necessary
-*/
-void QwtDial::changeEvent( QEvent *event )
+   Invalidates internal paint caches if necessary
+ */
+void QwtDial::changeEvent( QEvent* event )
 {
     switch( event->type() )
     {
@@ -825,20 +823,25 @@ void QwtDial::changeEvent( QEvent *event )
 }
 
 /*!
-  Wheel Event handler
-  \param event Wheel event
-*/
-void QwtDial::wheelEvent( QWheelEvent *event )
+   Wheel Event handler
+   \param event Wheel event
+ */
+void QwtDial::wheelEvent( QWheelEvent* event )
 {
+#if QT_VERSION < 0x050e00
+    const QPoint wheelPos = event->pos();
+#else
+    const QPoint wheelPos = event->position().toPoint();
+#endif
+
     const QRegion region( innerRect(), QRegion::Ellipse );
-    if ( region.contains( event->pos() ) )
+    if ( region.contains( wheelPos ) )
         QwtAbstractSlider::wheelEvent( event );
 }
 
 void QwtDial::setAngleRange( double angle, double span )
 {
-    QwtRoundScaleDraw *sd = const_cast<QwtRoundScaleDraw *>( scaleDraw() );
-    if ( sd  )
+    if ( QwtRoundScaleDraw* sd = scaleDraw() )
     {
         angle = qwtNormalizeDegrees( angle - 270.0 );
         sd->setAngleRange( angle, angle + span );
@@ -846,8 +849,8 @@ void QwtDial::setAngleRange( double angle, double span )
 }
 
 /*!
-  Invalidate the internal caches and call
-  QwtAbstractSlider::scaleChange()
+   Invalidate the internal caches and call
+   QwtAbstractSlider::scaleChange()
  */
 void QwtDial::scaleChange()
 {
@@ -857,15 +860,17 @@ void QwtDial::scaleChange()
 
 void QwtDial::sliderChange()
 {
-    setAngleRange( d_data->origin + d_data->minScaleArc,
-        d_data->maxScaleArc - d_data->minScaleArc );
+    setAngleRange( m_data->origin + m_data->minScaleArc,
+        m_data->maxScaleArc - m_data->minScaleArc );
 
     if ( mode() == RotateScale )
     {
         const double arc = scaleMap().transform( value() ) - scaleMap().p1();
-        setAngleRange( d_data->origin - arc,
-            d_data->maxScaleArc - d_data->minScaleArc );
+        setAngleRange( m_data->origin - arc,
+            m_data->maxScaleArc - m_data->minScaleArc );
     }
 
     QwtAbstractSlider::sliderChange();
 }
+
+#include "moc_qwt_dial.cpp"
