@@ -1,4 +1,4 @@
-/* -*- mode: C++ ; c-file-style: "stroustrup" -*- *****************************
+/******************************************************************************
  * Qwt Widget Library
  * Copyright (C) 1997   Josef Wilgen
  * Copyright (C) 2002   Uwe Rathmann
@@ -9,25 +9,23 @@
 
 #include "qwt_legend_label.h"
 #include "qwt_legend_data.h"
-#include "qwt_math.h"
-#include "qwt_painter.h"
-#include "qwt_symbol.h"
 #include "qwt_graphic.h"
+#include "qwt_painter.h"
+#include "qwt.h"
+
 #include <qpainter.h>
 #include <qdrawutil.h>
 #include <qstyle.h>
-#include <qpen.h>
 #include <qevent.h>
 #include <qstyleoption.h>
-#include <qapplication.h>
 
 static const int ButtonFrame = 2;
 static const int Margin = 2;
 
-static QSize buttonShift( const QwtLegendLabel *w )
+static QSize buttonShift( const QwtLegendLabel* w )
 {
     QStyleOption option;
-    option.init( w );
+    option.initFrom( w );
 
     const int ph = w->style()->pixelMetric(
         QStyle::PM_ButtonShiftHorizontal, &option, w );
@@ -38,11 +36,11 @@ static QSize buttonShift( const QwtLegendLabel *w )
 
 class QwtLegendLabel::PrivateData
 {
-public:
-    PrivateData():
-        itemMode( QwtLegendData::ReadOnly ),
-        isDown( false ),
-        spacing( Margin )
+  public:
+    PrivateData()
+        : itemMode( QwtLegendData::ReadOnly )
+        , isDown( false )
+        , spacing( Margin )
     {
     }
 
@@ -56,17 +54,18 @@ public:
 };
 
 /*!
-  Set the attributes of the legend label
+   Set the attributes of the legend label
 
-  \param legendData Attributes of the label
-  \sa data()
+   \param legendData Attributes of the label
+   \sa data()
  */
-void QwtLegendLabel::setData( const QwtLegendData &legendData )
+void QwtLegendLabel::setData( const QwtLegendData& legendData )
 {
-    d_data->legendData = legendData;
+    m_data->legendData = legendData;
 
     const bool doUpdate = updatesEnabled();
-    setUpdatesEnabled( false );
+    if ( doUpdate )
+        setUpdatesEnabled( false );
 
     setText( legendData.title() );
     setIcon( legendData.icon().toPixmap() );
@@ -75,28 +74,25 @@ void QwtLegendLabel::setData( const QwtLegendData &legendData )
         setItemMode( legendData.mode() );
 
     if ( doUpdate )
-    {
         setUpdatesEnabled( true );
-        update();
-    }
 }
 
 /*!
-  \return Attributes of the label
-  \sa setData(), QwtPlotItem::legendData()
+   \return Attributes of the label
+   \sa setData(), QwtPlotItem::legendData()
  */
-const QwtLegendData &QwtLegendLabel::data() const
+const QwtLegendData& QwtLegendLabel::data() const
 {
-    return d_data->legendData;
+    return m_data->legendData;
 }
 
 /*!
-  \param parent Parent widget
-*/
-QwtLegendLabel::QwtLegendLabel( QWidget *parent ):
-    QwtTextLabel( parent )
+   \param parent Parent widget
+ */
+QwtLegendLabel::QwtLegendLabel( QWidget* parent )
+    : QwtTextLabel( parent )
 {
-    d_data = new PrivateData;
+    m_data = new PrivateData;
     setMargin( Margin );
     setIndent( Margin );
 }
@@ -104,8 +100,8 @@ QwtLegendLabel::QwtLegendLabel( QWidget *parent ):
 //! Destructor
 QwtLegendLabel::~QwtLegendLabel()
 {
-    delete d_data;
-    d_data = NULL;
+    delete m_data;
+    m_data = NULL;
 }
 
 /*!
@@ -113,8 +109,8 @@ QwtLegendLabel::~QwtLegendLabel()
 
    \param text Text label
     \sa QwtTextLabel::text()
-*/
-void QwtLegendLabel::setText( const QwtText &text )
+ */
+void QwtLegendLabel::setText( const QwtText& text )
 {
     const int flags = Qt::AlignLeft | Qt::AlignVCenter
         | Qt::TextExpandTabs | Qt::TextWordWrap;
@@ -131,13 +127,13 @@ void QwtLegendLabel::setText( const QwtText &text )
 
    \param mode Item mode
    \sa itemMode()
-*/
+ */
 void QwtLegendLabel::setItemMode( QwtLegendData::Mode mode )
 {
-    if ( mode != d_data->itemMode )
+    if ( mode != m_data->itemMode )
     {
-        d_data->itemMode = mode;
-        d_data->isDown = false;
+        m_data->itemMode = mode;
+        m_data->isDown = false;
 
         setFocusPolicy( ( mode != QwtLegendData::ReadOnly )
             ? Qt::TabFocus : Qt::NoFocus );
@@ -150,37 +146,40 @@ void QwtLegendLabel::setItemMode( QwtLegendData::Mode mode )
 /*!
    \return Item mode
    \sa setItemMode()
-*/
+ */
 QwtLegendData::Mode QwtLegendLabel::itemMode() const
 {
-    return d_data->itemMode;
+    return m_data->itemMode;
 }
 
 /*!
-  Assign the icon
+   Assign the icon
 
-  \param icon Pixmap representing a plot item
+   \param icon Pixmap representing a plot item
 
-  \sa icon(), QwtPlotItem::legendIcon()
-*/
-void QwtLegendLabel::setIcon( const QPixmap &icon )
+   \sa icon(), QwtPlotItem::legendIcon()
+ */
+void QwtLegendLabel::setIcon( const QPixmap& icon )
 {
-    d_data->icon = icon;
+    m_data->icon = icon;
 
-    int indent = margin() + d_data->spacing;
+    int indent = margin() + m_data->spacing;
     if ( icon.width() > 0 )
-        indent += icon.width() + d_data->spacing;
+    {
+        const qreal devicePixelRatio = QwtPainter::devicePixelRatio( &icon );
+        indent += icon.width() / devicePixelRatio + m_data->spacing;
+    }
 
     setIndent( indent );
 }
 
 /*!
-  \return Pixmap representing a plot item
-  \sa setIcon()
-*/
+   \return Pixmap representing a plot item
+   \sa setIcon()
+ */
 QPixmap QwtLegendLabel::icon() const
 {
-    return d_data->icon;
+    return m_data->icon;
 }
 
 /*!
@@ -188,17 +187,17 @@ QPixmap QwtLegendLabel::icon() const
 
    \param spacing Spacing
    \sa spacing(), QwtTextLabel::margin()
-*/
+ */
 void QwtLegendLabel::setSpacing( int spacing )
 {
     spacing = qMax( spacing, 0 );
-    if ( spacing != d_data->spacing )
+    if ( spacing != m_data->spacing )
     {
-        d_data->spacing = spacing;
+        m_data->spacing = spacing;
 
-        int indent = margin() + d_data->spacing;
-        if ( d_data->icon.width() > 0 )
-            indent += d_data->icon.width() + d_data->spacing;
+        int indent = margin() + m_data->spacing;
+        if ( m_data->icon.width() > 0 )
+            indent += m_data->icon.width() + m_data->spacing;
 
         setIndent( indent );
     }
@@ -207,10 +206,10 @@ void QwtLegendLabel::setSpacing( int spacing )
 /*!
    \return Spacing between icon and text
    \sa setSpacing(), QwtTextLabel::margin()
-*/
+ */
 int QwtLegendLabel::spacing() const
 {
-    return d_data->spacing;
+    return m_data->spacing;
 }
 
 /*!
@@ -218,10 +217,10 @@ int QwtLegendLabel::spacing() const
 
     \param on check/uncheck
     \sa setItemMode()
-*/
+ */
 void QwtLegendLabel::setChecked( bool on )
 {
-    if ( d_data->itemMode == QwtLegendData::Checkable )
+    if ( m_data->itemMode == QwtLegendData::Checkable )
     {
         const bool isBlocked = signalsBlocked();
         blockSignals( true );
@@ -235,21 +234,21 @@ void QwtLegendLabel::setChecked( bool on )
 //! Return true, if the item is checked
 bool QwtLegendLabel::isChecked() const
 {
-    return d_data->itemMode == QwtLegendData::Checkable && isDown();
+    return m_data->itemMode == QwtLegendData::Checkable && isDown();
 }
 
 //! Set the item being down
 void QwtLegendLabel::setDown( bool down )
 {
-    if ( down == d_data->isDown )
+    if ( down == m_data->isDown )
         return;
 
-    d_data->isDown = down;
+    m_data->isDown = down;
     update();
 
-    if ( d_data->itemMode == QwtLegendData::Clickable )
+    if ( m_data->itemMode == QwtLegendData::Clickable )
     {
-        if ( d_data->isDown )
+        if ( m_data->isDown )
             Q_EMIT pressed();
         else
         {
@@ -258,40 +257,40 @@ void QwtLegendLabel::setDown( bool down )
         }
     }
 
-    if ( d_data->itemMode == QwtLegendData::Checkable )
-        Q_EMIT checked( d_data->isDown );
+    if ( m_data->itemMode == QwtLegendData::Checkable )
+        Q_EMIT checked( m_data->isDown );
 }
 
 //! Return true, if the item is down
 bool QwtLegendLabel::isDown() const
 {
-    return d_data->isDown;
+    return m_data->isDown;
 }
 
 //! Return a size hint
 QSize QwtLegendLabel::sizeHint() const
 {
     QSize sz = QwtTextLabel::sizeHint();
-    sz.setHeight( qMax( sz.height(), d_data->icon.height() + 4 ) );
+    sz.setHeight( qMax( sz.height(), m_data->icon.height() + 4 ) );
 
-    if ( d_data->itemMode != QwtLegendData::ReadOnly )
+    if ( m_data->itemMode != QwtLegendData::ReadOnly )
     {
         sz += buttonShift( this );
-        sz = sz.expandedTo( QApplication::globalStrut() );
+        sz = qwtExpandedToGlobalStrut( sz );
     }
 
     return sz;
 }
 
 //! Paint event
-void QwtLegendLabel::paintEvent( QPaintEvent *e )
+void QwtLegendLabel::paintEvent( QPaintEvent* e )
 {
     const QRect cr = contentsRect();
 
     QPainter painter( this );
     painter.setClipRegion( e->region() );
 
-    if ( d_data->isDown )
+    if ( m_data->isDown )
     {
         qDrawWinButton( &painter, 0, 0, width(), height(),
             palette(), true );
@@ -299,7 +298,7 @@ void QwtLegendLabel::paintEvent( QPaintEvent *e )
 
     painter.save();
 
-    if ( d_data->isDown )
+    if ( m_data->isDown )
     {
         const QSize shiftSize = buttonShift( this );
         painter.translate( shiftSize.width(), shiftSize.height() );
@@ -309,28 +308,29 @@ void QwtLegendLabel::paintEvent( QPaintEvent *e )
 
     drawContents( &painter );
 
-    if ( !d_data->icon.isNull() )
+    if ( !m_data->icon.isNull() )
     {
         QRect iconRect = cr;
         iconRect.setX( iconRect.x() + margin() );
-        if ( d_data->itemMode != QwtLegendData::ReadOnly )
+        if ( m_data->itemMode != QwtLegendData::ReadOnly )
             iconRect.setX( iconRect.x() + ButtonFrame );
 
-        iconRect.setSize( d_data->icon.size() );
+        const qreal devicePixelRatio = QwtPainter::devicePixelRatio( &m_data->icon );
+        iconRect.setSize( m_data->icon.size() / devicePixelRatio );
         iconRect.moveCenter( QPoint( iconRect.center().x(), cr.center().y() ) );
 
-        painter.drawPixmap( iconRect, d_data->icon );
+        painter.drawPixmap( iconRect, m_data->icon );
     }
 
     painter.restore();
 }
 
 //! Handle mouse press events
-void QwtLegendLabel::mousePressEvent( QMouseEvent *e )
+void QwtLegendLabel::mousePressEvent( QMouseEvent* e )
 {
     if ( e->button() == Qt::LeftButton )
     {
-        switch ( d_data->itemMode )
+        switch ( m_data->itemMode )
         {
             case QwtLegendData::Clickable:
             {
@@ -349,11 +349,11 @@ void QwtLegendLabel::mousePressEvent( QMouseEvent *e )
 }
 
 //! Handle mouse release events
-void QwtLegendLabel::mouseReleaseEvent( QMouseEvent *e )
+void QwtLegendLabel::mouseReleaseEvent( QMouseEvent* e )
 {
     if ( e->button() == Qt::LeftButton )
     {
-        switch ( d_data->itemMode )
+        switch ( m_data->itemMode )
         {
             case QwtLegendData::Clickable:
             {
@@ -371,11 +371,11 @@ void QwtLegendLabel::mouseReleaseEvent( QMouseEvent *e )
 }
 
 //! Handle key press events
-void QwtLegendLabel::keyPressEvent( QKeyEvent *e )
+void QwtLegendLabel::keyPressEvent( QKeyEvent* e )
 {
     if ( e->key() == Qt::Key_Space )
     {
-        switch ( d_data->itemMode )
+        switch ( m_data->itemMode )
         {
             case QwtLegendData::Clickable:
             {
@@ -397,11 +397,11 @@ void QwtLegendLabel::keyPressEvent( QKeyEvent *e )
 }
 
 //! Handle key release events
-void QwtLegendLabel::keyReleaseEvent( QKeyEvent *e )
+void QwtLegendLabel::keyReleaseEvent( QKeyEvent* e )
 {
     if ( e->key() == Qt::Key_Space )
     {
-        switch ( d_data->itemMode )
+        switch ( m_data->itemMode )
         {
             case QwtLegendData::Clickable:
             {
@@ -419,3 +419,5 @@ void QwtLegendLabel::keyReleaseEvent( QKeyEvent *e )
 
     QwtTextLabel::keyReleaseEvent( e );
 }
+
+#include "moc_qwt_legend_label.cpp"
