@@ -1,4 +1,4 @@
-/* -*- mode: C++ ; c-file-style: "stroustrup" -*- *****************************
+/******************************************************************************
  * Qwt Widget Library
  * Copyright (C) 1997   Josef Wilgen
  * Copyright (C) 2002   Uwe Rathmann
@@ -10,31 +10,19 @@
 #include "qwt_plot_panner.h"
 #include "qwt_scale_div.h"
 #include "qwt_plot.h"
+#include "qwt_scale_map.h"
 #include "qwt_painter.h"
+
 #include <qbitmap.h>
 #include <qstyle.h>
 #include <qstyleoption.h>
+#include <qpainter.h>
+#include <qpainterpath.h>
 
-#if QT_VERSION >= 0x050000
-#if QT_VERSION < 0x050100
-#define QWT_USE_WINDOW_HANDLE 1
-#endif
-#endif
-
-#ifdef QWT_USE_WINDOW_HANDLE
-#include <qwindow.h>
-#endif
-
-static QBitmap qwtBorderMask( const QWidget *canvas, const QSize &size )
+static QBitmap qwtBorderMask( const QWidget* canvas, const QSize& size )
 {
 #if QT_VERSION >= 0x050000
-    qreal pixelRatio = 1.0;
-
-#ifdef QWT_USE_WINDOW_HANDLE
-    pixelRatio = canvas->windowHandle()->devicePixelRatio();
-#else
-    pixelRatio = canvas->devicePixelRatio();
-#endif
+    const qreal pixelRatio = QwtPainter::devicePixelRatio( canvas );
 #endif
 
     const QRect r( 0, 0, size.width(), size.height() );
@@ -42,7 +30,7 @@ static QBitmap qwtBorderMask( const QWidget *canvas, const QSize &size )
     QPainterPath borderPath;
 
     ( void )QMetaObject::invokeMethod(
-        const_cast< QWidget *>( canvas ), "borderPath", Qt::DirectConnection,
+        const_cast< QWidget* >( canvas ), "borderPath", Qt::DirectConnection,
         Q_RETURN_ARG( QPainterPath, borderPath ), Q_ARG( QRect, r ) );
 
     if ( borderPath.isEmpty() )
@@ -51,7 +39,7 @@ static QBitmap qwtBorderMask( const QWidget *canvas, const QSize &size )
             return QBitmap();
 
 #if QT_VERSION >= 0x050000
-        QBitmap mask( size * pixelRatio );
+        QBitmap mask( size* pixelRatio );
         mask.setDevicePixelRatio( pixelRatio );
 #else
         QBitmap mask( size );
@@ -65,7 +53,7 @@ static QBitmap qwtBorderMask( const QWidget *canvas, const QSize &size )
     }
 
 #if QT_VERSION >= 0x050000
-    QImage image( size * pixelRatio, QImage::Format_ARGB32_Premultiplied );
+    QImage image( size* pixelRatio, QImage::Format_ARGB32_Premultiplied );
     image.setDevicePixelRatio( pixelRatio );
 #else
     QImage image( size, QImage::Format_ARGB32_Premultiplied );
@@ -92,11 +80,10 @@ static QBitmap qwtBorderMask( const QWidget *canvas, const QSize &size )
         const QVariant borderRadius = canvas->property( "borderRadius" );
         const QVariant frameWidth = canvas->property( "frameWidth" );
 
-        if ( borderRadius.type() == QVariant::Double
-            && frameWidth.type() == QVariant::Int )
+        if ( borderRadius.canConvert< double >() && frameWidth.canConvert< int >() )
         {
-            const double br = borderRadius.toDouble();
-            const int fw = frameWidth.toInt();
+            const double br = borderRadius.value< double >();
+            const int fw = frameWidth.value< int >();
 
             if ( br > 0.0 && fw > 0 )
             {
@@ -119,29 +106,29 @@ static QBitmap qwtBorderMask( const QWidget *canvas, const QSize &size )
 
 class QwtPlotPanner::PrivateData
 {
-public:
+  public:
     PrivateData()
     {
-        for ( int axis = 0; axis < QwtPlot::axisCnt; axis++ )
+        for ( int axis = 0; axis < QwtAxis::AxisPositions; axis++ )
             isAxisEnabled[axis] = true;
     }
 
-    bool isAxisEnabled[QwtPlot::axisCnt];
+    bool isAxisEnabled[QwtAxis::AxisPositions];
 };
 
 /*!
-  \brief A panner for the canvas of a QwtPlot
+   \brief A panner for the canvas of a QwtPlot
 
-  The panner is enabled for all axes
+   The panner is enabled for all axes
 
-  \param canvas Plot canvas to pan, also the parent object
+   \param canvas Plot canvas to pan, also the parent object
 
-  \sa setAxisEnabled()
-*/
-QwtPlotPanner::QwtPlotPanner( QWidget *canvas ):
-    QwtPanner( canvas )
+   \sa setAxisEnabled()
+ */
+QwtPlotPanner::QwtPlotPanner( QWidget* canvas )
+    : QwtPanner( canvas )
 {
-    d_data = new PrivateData();
+    m_data = new PrivateData();
 
     connect( this, SIGNAL(panned(int,int)),
         SLOT(moveCanvas(int,int)) );
@@ -150,7 +137,7 @@ QwtPlotPanner::QwtPlotPanner( QWidget *canvas ):
 //! Destructor
 QwtPlotPanner::~QwtPlotPanner()
 {
-    delete d_data;
+    delete m_data;
 }
 
 /*!
@@ -159,63 +146,63 @@ QwtPlotPanner::~QwtPlotPanner()
    Axes that are enabled will be synchronized to the
    result of panning. All other axes will remain unchanged.
 
-   \param axis Axis, see QwtPlot::Axis
+   \param axisId Axis id
    \param on On/Off
 
    \sa isAxisEnabled(), moveCanvas()
-*/
-void QwtPlotPanner::setAxisEnabled( int axis, bool on )
+ */
+void QwtPlotPanner::setAxisEnabled( QwtAxisId axisId, bool on )
 {
-    if ( axis >= 0 && axis < QwtPlot::axisCnt )
-        d_data->isAxisEnabled[axis] = on;
+    if ( QwtAxis::isValid( axisId ) )
+        m_data->isAxisEnabled[axisId] = on;
 }
 
 /*!
    Test if an axis is enabled
 
-   \param axis Axis, see QwtPlot::Axis
+   \param axisId Axis
    \return True, if the axis is enabled
 
    \sa setAxisEnabled(), moveCanvas()
-*/
-bool QwtPlotPanner::isAxisEnabled( int axis ) const
+ */
+bool QwtPlotPanner::isAxisEnabled( QwtAxisId axisId ) const
 {
-    if ( axis >= 0 && axis < QwtPlot::axisCnt )
-        return d_data->isAxisEnabled[axis];
+    if ( QwtAxis::isValid( axisId ) )
+        return m_data->isAxisEnabled[axisId];
 
     return true;
 }
 
 //! Return observed plot canvas
-QWidget *QwtPlotPanner::canvas()
+QWidget* QwtPlotPanner::canvas()
 {
     return parentWidget();
 }
 
 //! Return Observed plot canvas
-const QWidget *QwtPlotPanner::canvas() const
+const QWidget* QwtPlotPanner::canvas() const
 {
     return parentWidget();
 }
 
 //! Return plot widget, containing the observed plot canvas
-QwtPlot *QwtPlotPanner::plot()
+QwtPlot* QwtPlotPanner::plot()
 {
-    QWidget *w = canvas();
+    QWidget* w = canvas();
     if ( w )
         w = w->parentWidget();
 
-    return qobject_cast<QwtPlot *>( w );
+    return qobject_cast< QwtPlot* >( w );
 }
 
 //! Return plot widget, containing the observed plot canvas
-const QwtPlot *QwtPlotPanner::plot() const
+const QwtPlot* QwtPlotPanner::plot() const
 {
-    const QWidget *w = canvas();
+    const QWidget* w = canvas();
     if ( w )
         w = w->parentWidget();
 
-    return qobject_cast<const QwtPlot *>( w );
+    return qobject_cast< const QwtPlot* >( w );
 }
 
 /*!
@@ -225,42 +212,46 @@ const QwtPlot *QwtPlotPanner::plot() const
    \param dy Pixel offset in y direction
 
    \sa QwtPanner::panned()
-*/
+ */
 void QwtPlotPanner::moveCanvas( int dx, int dy )
 {
     if ( dx == 0 && dy == 0 )
         return;
 
-    QwtPlot *plot = this->plot();
+    QwtPlot* plot = this->plot();
     if ( plot == NULL )
         return;
 
     const bool doAutoReplot = plot->autoReplot();
     plot->setAutoReplot( false );
 
-    for ( int axis = 0; axis < QwtPlot::axisCnt; axis++ )
+    for ( int axisPos = 0; axisPos < QwtAxis::AxisPositions; axisPos++ )
     {
-        if ( !d_data->isAxisEnabled[axis] )
-            continue;
-
-        const QwtScaleMap map = plot->canvasMap( axis );
-
-        const double p1 = map.transform( plot->axisScaleDiv( axis ).lowerBound() );
-        const double p2 = map.transform( plot->axisScaleDiv( axis ).upperBound() );
-
-        double d1, d2;
-        if ( axis == QwtPlot::xBottom || axis == QwtPlot::xTop )
         {
-            d1 = map.invTransform( p1 - dx );
-            d2 = map.invTransform( p2 - dx );
-        }
-        else
-        {
-            d1 = map.invTransform( p1 - dy );
-            d2 = map.invTransform( p2 - dy );
-        }
+            const QwtAxisId axisId( axisPos );
 
-        plot->setAxisScale( axis, d1, d2 );
+            if ( !m_data->isAxisEnabled[axisId] )
+                continue;
+
+            const QwtScaleMap map = plot->canvasMap( axisId );
+
+            const double p1 = map.transform( plot->axisScaleDiv( axisId ).lowerBound() );
+            const double p2 = map.transform( plot->axisScaleDiv( axisId ).upperBound() );
+
+            double d1, d2;
+            if ( QwtAxis::isXAxis( axisPos ) )
+            {
+                d1 = map.invTransform( p1 - dx );
+                d2 = map.invTransform( p2 - dx );
+            }
+            else
+            {
+                d1 = map.invTransform( p1 - dy );
+                d2 = map.invTransform( p2 - dy );
+            }
+
+            plot->setAxisScale( axisId, d1, d2 );
+        }
     }
 
     plot->setAutoReplot( doAutoReplot );
@@ -272,7 +263,7 @@ void QwtPlotPanner::moveCanvas( int dx, int dy )
 
    \return Mask as bitmap
    \sa QwtPlotCanvas::borderPath()
-*/
+ */
 QBitmap QwtPlotPanner::contentsMask() const
 {
     if ( canvas() )
@@ -286,7 +277,7 @@ QBitmap QwtPlotPanner::contentsMask() const
  */
 QPixmap QwtPlotPanner::grab() const
 {
-    const QWidget *cv = canvas();
+    const QWidget* cv = canvas();
     if ( cv && cv->inherits( "QGLWidget" ) )
     {
         // we can't grab from a QGLWidget
@@ -295,7 +286,7 @@ QPixmap QwtPlotPanner::grab() const
         QwtPainter::fillPixmap( cv, pm );
 
         QPainter painter( &pm );
-        const_cast<QwtPlot *>( plot() )->drawCanvas( &painter );
+        const_cast< QwtPlot* >( plot() )->drawCanvas( &painter );
 
         return pm;
     }
@@ -303,3 +294,4 @@ QPixmap QwtPlotPanner::grab() const
     return QwtPanner::grab();
 }
 
+#include "moc_qwt_plot_panner.cpp"
