@@ -1,4 +1,4 @@
-/* -*- mode: C++ ; c-file-style: "stroustrup" -*- *****************************
+/******************************************************************************
  * Qwt Widget Library
  * Copyright (C) 1997   Josef Wilgen
  * Copyright (C) 2002   Uwe Rathmann
@@ -10,24 +10,24 @@
 #include "qwt_plot_rasteritem.h"
 #include "qwt_scale_map.h"
 #include "qwt_painter.h"
-#include <qapplication.h>
-#include <qdesktopwidget.h>
+#include "qwt_text.h"
+#include "qwt_interval.h"
+#include "qwt_math.h"
+
 #include <qpainter.h>
 #include <qpaintengine.h>
-#include <qmath.h>
-#if QT_VERSION >= 0x040400
 #include <qthread.h>
 #include <qfuture.h>
 #include <qtconcurrentrun.h>
-#endif
-#include <float.h>
+
+#include <limits>
 
 class QwtPlotRasterItem::PrivateData
 {
-public:
-    PrivateData():
-        alpha( -1 ),
-        paintAttributes( QwtPlotRasterItem::PaintInDeviceResolution )
+  public:
+    PrivateData()
+        : alpha( -1 )
+        , paintAttributes( QwtPlotRasterItem::PaintInDeviceResolution )
     {
         cache.policy = QwtPlotRasterItem::NoCache;
     }
@@ -46,7 +46,7 @@ public:
 };
 
 
-static QRectF qwtAlignRect(const QRectF &rect)
+static QRectF qwtAlignRect(const QRectF& rect)
 {
     QRectF r;
     r.setLeft( qRound( rect.left() ) );
@@ -57,9 +57,9 @@ static QRectF qwtAlignRect(const QRectF &rect)
     return r;
 }
 
-static QRectF qwtStripRect(const QRectF &rect, const QRectF &area,
-    const QwtScaleMap &xMap, const QwtScaleMap &yMap,
-    const QwtInterval &xInterval, const QwtInterval &yInterval)
+static QRectF qwtStripRect(const QRectF& rect, const QRectF& area,
+    const QwtScaleMap& xMap, const QwtScaleMap& yMap,
+    const QwtInterval& xInterval, const QwtInterval& yInterval)
 {
     QRectF r = rect;
     if ( xInterval.borderFlags() & QwtInterval::ExcludeMinimum )
@@ -109,10 +109,10 @@ static QRectF qwtStripRect(const QRectF &rect, const QRectF &area,
     return r;
 }
 
-static QImage qwtExpandImage(const QImage &image,
-    const QwtScaleMap &xMap, const QwtScaleMap &yMap,
-    const QRectF &area, const QRectF &area2, const QRectF &paintRect,
-    const QwtInterval &xInterval, const QwtInterval &yInterval )
+static QImage qwtExpandImage(const QImage& image,
+    const QwtScaleMap& xMap, const QwtScaleMap& yMap,
+    const QRectF& area, const QRectF& area2, const QRectF& paintRect,
+    const QwtInterval& xInterval, const QwtInterval& yInterval )
 {
     const QRectF strippedRect = qwtStripRect(paintRect, area2,
         xMap, yMap, xInterval, yInterval);
@@ -122,8 +122,8 @@ static QImage qwtExpandImage(const QImage &image,
     const int h = image.height();
 
     const QRectF r = QwtScaleMap::transform(xMap, yMap, area).normalized();
-    const double pw = ( r.width() - 1) / w;
-    const double ph = ( r.height() - 1) / h;
+    const double pw = ( r.width() - 1 ) / w;
+    const double ph = ( r.height() - 1 ) / h;
 
     double px0, py0;
     if ( !xMap.isInverting() )
@@ -158,7 +158,9 @@ static QImage qwtExpandImage(const QImage &image,
     }
     py0 += strippedRect.top() - paintRect.top();
 
-    QImage expanded(sz, image.format());
+    QImage expanded( sz, image.format() );
+    if ( image.format() == QImage::Format_Indexed8 )
+        expanded.setColorTable( image.colorTable() );
 
     switch( image.depth() )
     {
@@ -190,8 +192,8 @@ static QImage qwtExpandImage(const QImage &image,
                         yy2 = sz.height();
                 }
 
-                const quint32 *line1 =
-                    reinterpret_cast<const quint32 *>( image.scanLine( y1 ) );
+                const quint32* line1 =
+                    reinterpret_cast< const quint32* >( image.scanLine( y1 ) );
 
                 for ( int x1 = 0; x1 < w; x1++ )
                 {
@@ -222,7 +224,7 @@ static QImage qwtExpandImage(const QImage &image,
                     const quint32 rgb( line1[x1] );
                     for ( int y2 = yy1; y2 < yy2; y2++ )
                     {
-                        quint32 *line2 = reinterpret_cast<quint32 *>(
+                        quint32* line2 = reinterpret_cast< quint32* >(
                             expanded.scanLine( y2 ) );
 
                         for ( int x2 = xx1; x2 < xx2; x2++ )
@@ -260,7 +262,7 @@ static QImage qwtExpandImage(const QImage &image,
                         yy2 = sz.height();
                 }
 
-                const uchar *line1 = image.scanLine( y1 );
+                const uchar* line1 = image.scanLine( y1 );
 
                 for ( int x1 = 0; x1 < w; x1++ )
                 {
@@ -290,7 +292,7 @@ static QImage qwtExpandImage(const QImage &image,
 
                     for ( int y2 = yy1; y2 < yy2; y2++ )
                     {
-                        uchar *line2 = expanded.scanLine( y2 );
+                        uchar* line2 = expanded.scanLine( y2 );
                         memset( line2 + xx1, line1[x1], xx2 - xx1 );
                     }
                 }
@@ -304,7 +306,7 @@ static QImage qwtExpandImage(const QImage &image,
     return expanded;
 }
 
-static QRectF qwtExpandToPixels(const QRectF &rect, const QRectF &pixelRect)
+static QRectF qwtExpandToPixels(const QRectF& rect, const QRectF& pixelRect)
 {
     const double pw = pixelRect.width();
     const double ph = pixelRect.height();
@@ -315,17 +317,17 @@ static QRectF qwtExpandToPixels(const QRectF &rect, const QRectF &pixelRect)
     const double dy2 = pixelRect.bottom() - rect.bottom();
 
     QRectF r;
-    r.setLeft( pixelRect.left() - qCeil( dx1 / pw ) * pw );
-    r.setTop( pixelRect.top() - qCeil( dy1 / ph ) * ph );
-    r.setRight( pixelRect.right() - qFloor( dx2 / pw ) * pw );
-    r.setBottom( pixelRect.bottom() - qFloor( dy2 / ph ) * ph );
+    r.setLeft( pixelRect.left() - qwtCeil( dx1 / pw ) * pw );
+    r.setTop( pixelRect.top() - qwtCeil( dy1 / ph ) * ph );
+    r.setRight( pixelRect.right() - qwtFloor( dx2 / pw ) * pw );
+    r.setBottom( pixelRect.bottom() - qwtFloor( dy2 / ph ) * ph );
 
     return r;
 }
 
-static void qwtTransformMaps( const QTransform &tr,
-    const QwtScaleMap &xMap, const QwtScaleMap &yMap,
-    QwtScaleMap &xxMap, QwtScaleMap &yyMap )
+static void qwtTransformMaps( const QTransform& tr,
+    const QwtScaleMap& xMap, const QwtScaleMap& yMap,
+    QwtScaleMap& xxMap, QwtScaleMap& yyMap )
 {
     const QPointF p1 = tr.map( QPointF( xMap.p1(), yMap.p1() ) );
     const QPointF p2 = tr.map( QPointF( xMap.p2(), yMap.p2() ) );
@@ -337,8 +339,8 @@ static void qwtTransformMaps( const QTransform &tr,
     yyMap.setPaintInterval( p1.y(), p2.y() );
 }
 
-static void qwtAdjustMaps( QwtScaleMap &xMap, QwtScaleMap &yMap,
-    const QRectF &area, const QRectF &paintRect)
+static void qwtAdjustMaps( QwtScaleMap& xMap, QwtScaleMap& yMap,
+    const QRectF& area, const QRectF& paintRect)
 {
     double sx1 = area.left();
     double sx2 = area.right();
@@ -351,15 +353,15 @@ static void qwtAdjustMaps( QwtScaleMap &xMap, QwtScaleMap &yMap,
     if ( yMap.isInverting() )
         qSwap(sy1, sy2);
 
-    xMap.setPaintInterval(paintRect.left(), paintRect.right());
+    xMap.setPaintInterval(paintRect.left(), paintRect.right() );
     xMap.setScaleInterval(sx1, sx2);
 
-    yMap.setPaintInterval(paintRect.top(), paintRect.bottom());
+    yMap.setPaintInterval(paintRect.top(), paintRect.bottom() );
     yMap.setScaleInterval(sy1, sy2);
 }
 
 static bool qwtUseCache( QwtPlotRasterItem::CachePolicy policy,
-    const QPainter *painter )
+    const QPainter* painter )
 {
     bool doCache = false;
 
@@ -372,7 +374,9 @@ static bool qwtUseCache( QwtPlotRasterItem::CachePolicy policy,
         {
             case QPaintEngine::SVG:
             case QPaintEngine::Pdf:
+#if QT_VERSION < 0x060000
             case QPaintEngine::PostScript:
+#endif
             case QPaintEngine::MacPrinter:
             case QPaintEngine::Picture:
                 break;
@@ -400,8 +404,8 @@ static void qwtToRgba( const QImage* from, QImage* to,
     {
         for ( int y = y0; y <= y1; y++ )
         {
-            QRgb *alphaLine = reinterpret_cast<QRgb *>( to->scanLine( y ) );
-            const unsigned char *line = from->scanLine( y );
+            QRgb* alphaLine = reinterpret_cast< QRgb* >( to->scanLine( y ) );
+            const unsigned char* line = from->scanLine( y );
 
             for ( int x = x0; x <= x1; x++ )
                 *alphaLine++ = ( from->color( *line++ ) & mask2 ) | mask1;
@@ -411,8 +415,8 @@ static void qwtToRgba( const QImage* from, QImage* to,
     {
         for ( int y = y0; y <= y1; y++ )
         {
-            QRgb *alphaLine = reinterpret_cast<QRgb *>( to->scanLine( y ) );
-            const QRgb *line = reinterpret_cast<const QRgb *>( from->scanLine( y ) );
+            QRgb* alphaLine = reinterpret_cast< QRgb* >( to->scanLine( y ) );
+            const QRgb* line = reinterpret_cast< const QRgb* >( from->scanLine( y ) );
 
             for ( int x = x0; x <= x1; x++ )
             {
@@ -427,15 +431,15 @@ static void qwtToRgba( const QImage* from, QImage* to,
 }
 
 //! Constructor
-QwtPlotRasterItem::QwtPlotRasterItem( const QString& title ):
-    QwtPlotItem( QwtText( title ) )
+QwtPlotRasterItem::QwtPlotRasterItem( const QString& title )
+    : QwtPlotItem( QwtText( title ) )
 {
     init();
 }
 
 //! Constructor
-QwtPlotRasterItem::QwtPlotRasterItem( const QwtText& title ):
-    QwtPlotItem( title )
+QwtPlotRasterItem::QwtPlotRasterItem( const QwtText& title )
+    : QwtPlotItem( title )
 {
     init();
 }
@@ -443,12 +447,12 @@ QwtPlotRasterItem::QwtPlotRasterItem( const QwtText& title ):
 //! Destructor
 QwtPlotRasterItem::~QwtPlotRasterItem()
 {
-    delete d_data;
+    delete m_data;
 }
 
 void QwtPlotRasterItem::init()
 {
-    d_data = new PrivateData();
+    m_data = new PrivateData();
 
     setItemAttribute( QwtPlotItem::AutoScale, true );
     setItemAttribute( QwtPlotItem::Legend, false );
@@ -457,27 +461,27 @@ void QwtPlotRasterItem::init()
 }
 
 /*!
-  Specify an attribute how to draw the raster item
+   Specify an attribute how to draw the raster item
 
-  \param attribute Paint attribute
-  \param on On/Off
-  /sa PaintAttribute, testPaintAttribute()
-*/
+   \param attribute Paint attribute
+   \param on On/Off
+   /sa PaintAttribute, testPaintAttribute()
+ */
 void QwtPlotRasterItem::setPaintAttribute( PaintAttribute attribute, bool on )
 {
     if ( on )
-        d_data->paintAttributes |= attribute;
+        m_data->paintAttributes |= attribute;
     else
-        d_data->paintAttributes &= ~attribute;
+        m_data->paintAttributes &= ~attribute;
 }
 
 /*!
     \return True, when attribute is enabled
     \sa PaintAttribute, setPaintAttribute()
-*/
+ */
 bool QwtPlotRasterItem::testPaintAttribute( PaintAttribute attribute ) const
 {
-    return ( d_data->paintAttributes & attribute );
+    return ( m_data->paintAttributes & attribute );
 }
 
 /*!
@@ -502,7 +506,7 @@ bool QwtPlotRasterItem::testPaintAttribute( PaintAttribute attribute ) const
    The default alpha value is -1.
 
    \sa alpha()
-*/
+ */
 void QwtPlotRasterItem::setAlpha( int alpha )
 {
     if ( alpha < 0 )
@@ -511,37 +515,37 @@ void QwtPlotRasterItem::setAlpha( int alpha )
     if ( alpha > 255 )
         alpha = 255;
 
-    if ( alpha != d_data->alpha )
+    if ( alpha != m_data->alpha )
     {
-        d_data->alpha = alpha;
+        m_data->alpha = alpha;
 
         itemChanged();
     }
 }
 
 /*!
-  \return Alpha value of the raster item
-  \sa setAlpha()
-*/
+   \return Alpha value of the raster item
+   \sa setAlpha()
+ */
 int QwtPlotRasterItem::alpha() const
 {
-    return d_data->alpha;
+    return m_data->alpha;
 }
 
 /*!
-  Change the cache policy
+   Change the cache policy
 
-  The default policy is NoCache
+   The default policy is NoCache
 
-  \param policy Cache policy
-  \sa CachePolicy, cachePolicy()
-*/
+   \param policy Cache policy
+   \sa CachePolicy, cachePolicy()
+ */
 void QwtPlotRasterItem::setCachePolicy(
     QwtPlotRasterItem::CachePolicy policy )
 {
-    if ( d_data->cache.policy != policy )
+    if ( m_data->cache.policy != policy )
     {
-        d_data->cache.policy = policy;
+        m_data->cache.policy = policy;
 
         invalidateCache();
         itemChanged();
@@ -549,23 +553,23 @@ void QwtPlotRasterItem::setCachePolicy(
 }
 
 /*!
-  \return Cache policy
-  \sa CachePolicy, setCachePolicy()
-*/
+   \return Cache policy
+   \sa CachePolicy, setCachePolicy()
+ */
 QwtPlotRasterItem::CachePolicy QwtPlotRasterItem::cachePolicy() const
 {
-    return d_data->cache.policy;
+    return m_data->cache.policy;
 }
 
 /*!
    Invalidate the paint cache
    \sa setCachePolicy()
-*/
+ */
 void QwtPlotRasterItem::invalidateCache()
 {
-    d_data->cache.image = QImage();
-    d_data->cache.area = QRect();
-    d_data->cache.size = QSize();
+    m_data->cache.image = QImage();
+    m_data->cache.area = QRect();
+    m_data->cache.size = QSize();
 }
 
 /*!
@@ -593,28 +597,28 @@ void QwtPlotRasterItem::invalidateCache()
    \return Bounding rectangle of a pixel
 
    \sa render(), renderImage()
-*/
-QRectF QwtPlotRasterItem::pixelHint( const QRectF &area ) const
+ */
+QRectF QwtPlotRasterItem::pixelHint( const QRectF& area ) const
 {
     Q_UNUSED( area );
     return QRectF();
 }
 
 /*!
-  \brief Draw the raster data
-  \param painter Painter
-  \param xMap X-Scale Map
-  \param yMap Y-Scale Map
-  \param canvasRect Contents rectangle of the plot canvas
-*/
-void QwtPlotRasterItem::draw( QPainter *painter,
-    const QwtScaleMap &xMap, const QwtScaleMap &yMap,
-    const QRectF &canvasRect ) const
+   \brief Draw the raster data
+   \param painter Painter
+   \param xMap X-Scale Map
+   \param yMap Y-Scale Map
+   \param canvasRect Contents rectangle of the plot canvas
+ */
+void QwtPlotRasterItem::draw( QPainter* painter,
+    const QwtScaleMap& xMap, const QwtScaleMap& yMap,
+    const QRectF& canvasRect ) const
 {
-    if ( canvasRect.isEmpty() || d_data->alpha == 0 )
+    if ( canvasRect.isEmpty() || m_data->alpha == 0 )
         return;
 
-    const bool doCache = qwtUseCache( d_data->cache.policy, painter );
+    const bool doCache = qwtUseCache( m_data->cache.policy, painter );
 
     const QwtInterval xInterval = interval( Qt::XAxis );
     const QwtInterval yInterval = interval( Qt::YAxis );
@@ -623,7 +627,7 @@ void QwtPlotRasterItem::draw( QPainter *painter,
         Scaling an image always results in a loss of
         precision/quality. So we always render the image in
         paint device resolution.
-    */
+     */
 
     QwtScaleMap xxMap, yyMap;
     qwtTransformMaps( painter->transform(), xMap, yMap, xxMap, yyMap );
@@ -654,17 +658,17 @@ void QwtPlotRasterItem::draw( QPainter *painter,
         if ( dx > pixelRect.width() && dy > pixelRect.height() )
         {
             /*
-              When the resolution of the data pixels is higher than
-              the resolution of the target device we render in
-              target device resolution.
+               When the resolution of the data pixels is higher than
+               the resolution of the target device we render in
+               target device resolution.
              */
             pixelRect = QRectF();
         }
         else
         {
             /*
-              If only one dimension is of the data pixel is higher
-              we expand the pixel rect to the resolution of the target device.
+               If only one dimension is of the data pixel is higher
+               we expand the pixel rect to the resolution of the target device.
              */
 
             if ( dx > pixelRect.width() )
@@ -689,11 +693,23 @@ void QwtPlotRasterItem::draw( QPainter *painter,
         // When we have no information about position and size of
         // data pixels we render in resolution of the paint device.
 
+        auto imageSize = paintRect.size();
+
+#if QT_VERSION >= 0x050000
+        const auto pixelRatio = QwtPainter::devicePixelRatio( painter->device() );
+        imageSize *= pixelRatio;
+#endif
+
         image = compose(xxMap, yyMap,
-            area, paintRect, paintRect.size().toSize(), doCache);
+            area, paintRect, imageSize.toSize(), doCache);
+
         if ( image.isNull() )
             return;
 
+#if QT_VERSION >= 0x050000
+        image.setDevicePixelRatio( pixelRatio );
+#endif
+
         // Remove pixels at the boundaries, when explicitly
         // excluded in the intervals
 
@@ -703,7 +719,7 @@ void QwtPlotRasterItem::draw( QPainter *painter,
         if ( imageRect != paintRect )
         {
             const QRect r(
-                qRound( imageRect.x() - paintRect.x()),
+                qRound( imageRect.x() - paintRect.x() ),
                 qRound( imageRect.y() - paintRect.y() ),
                 qRound( imageRect.width() ),
                 qRound( imageRect.height() ) );
@@ -770,7 +786,7 @@ void QwtPlotRasterItem::draw( QPainter *painter,
    The default implementation returns an invalid interval.
 
    \param axis X, Y, or Z axis
-*/
+ */
 QwtInterval QwtPlotRasterItem::interval(Qt::Axis axis) const
 {
     Q_UNUSED( axis );
@@ -780,7 +796,7 @@ QwtInterval QwtPlotRasterItem::interval(Qt::Axis axis) const
 /*!
    \return Bounding rectangle of the data
    \sa QwtPlotRasterItem::interval()
-*/
+ */
 QRectF QwtPlotRasterItem::boundingRect() const
 {
     const QwtInterval intervalX = interval( Qt::XAxis );
@@ -798,8 +814,10 @@ QRectF QwtPlotRasterItem::boundingRect() const
     }
     else
     {
-        r.setLeft(-0.5 * FLT_MAX);
-        r.setWidth(FLT_MAX);
+        const qreal max = std::numeric_limits< float >::max();
+
+        r.setLeft( -0.5 * max );
+        r.setWidth( max );
     }
 
     if ( intervalY.isValid() )
@@ -809,17 +827,19 @@ QRectF QwtPlotRasterItem::boundingRect() const
     }
     else
     {
-        r.setTop(-0.5 * FLT_MAX);
-        r.setHeight(FLT_MAX);
+        const qreal max = std::numeric_limits< float >::max();
+
+        r.setTop( -0.5 * max );
+        r.setHeight( max );
     }
 
     return r.normalized();
 }
 
 QImage QwtPlotRasterItem::compose(
-    const QwtScaleMap &xMap, const QwtScaleMap &yMap,
-    const QRectF &imageArea, const QRectF &paintRect,
-    const QSize &imageSize, bool doCache) const
+    const QwtScaleMap& xMap, const QwtScaleMap& yMap,
+    const QRectF& imageArea, const QRectF& paintRect,
+    const QSize& imageSize, bool doCache) const
 {
     QImage image;
     if ( imageArea.isEmpty() || paintRect.isEmpty() || imageSize.isEmpty() )
@@ -827,11 +847,11 @@ QImage QwtPlotRasterItem::compose(
 
     if ( doCache )
     {
-        if ( !d_data->cache.image.isNull()
-            && d_data->cache.area == imageArea
-            && d_data->cache.size == paintRect.size() )
+        if ( !m_data->cache.image.isNull()
+            && m_data->cache.area == imageArea
+            && m_data->cache.size == paintRect.size() )
         {
-            image = d_data->cache.image;
+            image = m_data->cache.image;
         }
     }
 
@@ -855,17 +875,17 @@ QImage QwtPlotRasterItem::compose(
 
         if ( doCache )
         {
-            d_data->cache.area = imageArea;
-            d_data->cache.size = paintRect.size();
-            d_data->cache.image = image;
+            m_data->cache.area = imageArea;
+            m_data->cache.size = paintRect.size();
+            m_data->cache.image = image;
         }
     }
 
-    if ( d_data->alpha >= 0 && d_data->alpha < 255 )
+    if ( m_data->alpha >= 0 && m_data->alpha < 255 )
     {
         QImage alphaImage( image.size(), QImage::Format_ARGB32 );
 
-#if QT_VERSION >= 0x040400 && !defined(QT_NO_QFUTURE)
+#if !defined( QT_NO_QFUTURE )
         uint numThreads = renderThreadCount();
 
         if ( numThreads <= 0 )
@@ -876,26 +896,28 @@ QImage QwtPlotRasterItem::compose(
 
         const int numRows = image.height() / numThreads;
 
-        QList< QFuture<void> > futures;
+        QVector< QFuture< void > > futures;
+        futures.reserve( numThreads - 1 );
+
         for ( uint i = 0; i < numThreads; i++ )
         {
             QRect tile( 0, i * numRows, image.width(), numRows );
             if ( i == numThreads - 1 )
             {
                 tile.setHeight( image.height() - i * numRows );
-                qwtToRgba( &image, &alphaImage, tile, d_data->alpha );
+                qwtToRgba( &image, &alphaImage, tile, m_data->alpha );
             }
             else
             {
                 futures += QtConcurrent::run(
-                    &qwtToRgba, &image, &alphaImage, tile, d_data->alpha );
+                    &qwtToRgba, &image, &alphaImage, tile, m_data->alpha );
             }
         }
         for ( int i = 0; i < futures.size(); i++ )
             futures[i].waitForFinished();
 #else
         const QRect tile( 0, 0, image.width(), image.height() );
-        qwtToRgba( &image, &alphaImage, tile, d_data->alpha );
+        qwtToRgba( &image, &alphaImage, tile, m_data->alpha );
 #endif
         image = alphaImage;
     }
@@ -913,11 +935,11 @@ QImage QwtPlotRasterItem::compose(
    \param pixelSize Width/Height of a data pixel
 
    \return Calculated scale map
-*/
+ */
 QwtScaleMap QwtPlotRasterItem::imageMap(
     Qt::Orientation orientation,
-    const QwtScaleMap &map, const QRectF &area,
-    const QSize &imageSize, double pixelSize) const
+    const QwtScaleMap& map, const QRectF& area,
+    const QSize& imageSize, double pixelSize) const
 {
     double p1, p2, s1, s2;
 
@@ -936,7 +958,7 @@ QwtScaleMap QwtPlotRasterItem::imageMap(
         s2 = area.bottom();
     }
 
-    if ( pixelSize > 0.0 )
+    if ( pixelSize > 0.0 || p2 == 1.0 )
     {
         double off = 0.5 * pixelSize;
         if ( map.isInverting() )
