@@ -1,4 +1,4 @@
-/* -*- mode: C++ ; c-file-style: "stroustrup" -*- *****************************
+/******************************************************************************
  * Qwt Widget Library
  * Copyright (C) 1997   Josef Wilgen
  * Copyright (C) 2002   Uwe Rathmann
@@ -11,16 +11,17 @@
 #include "qwt_painter.h"
 #include "qwt_scale_draw.h"
 #include "qwt_scale_map.h"
+#include "qwt_math.h"
+#include "qwt.h"
+
 #include <qevent.h>
 #include <qdrawutil.h>
 #include <qpainter.h>
-#include <qalgorithms.h>
-#include <qmath.h>
 #include <qstyle.h>
 #include <qstyleoption.h>
-#include <qapplication.h>
+#include <qmargins.h>
 
-static QSize qwtHandleSize( const QSize &size,
+static QSize qwtHandleSize( const QSize& size,
     Qt::Orientation orientation, bool hasTrough )
 {
     QSize handleSize = size;
@@ -68,18 +69,18 @@ static QwtScaleDraw::Alignment qwtScaleDrawAlignment(
 
 class QwtSlider::PrivateData
 {
-public:
-    PrivateData():
-        repeatTimerId( 0 ),
-        updateInterval( 150 ),
-        stepsIncrement( 0 ),
-        pendingValueChange( false ),
-        borderWidth( 2 ),
-        spacing( 4 ),
-        scalePosition( QwtSlider::TrailingScale ),
-        hasTrough( true ),
-        hasGroove( false ),
-        mouseOffset( 0 )
+  public:
+    PrivateData()
+        : repeatTimerId( 0 )
+        , updateInterval( 150 )
+        , stepsIncrement( 0 )
+        , pendingValueChange( false )
+        , borderWidth( 2 )
+        , spacing( 4 )
+        , scalePosition( QwtSlider::TrailingScale )
+        , hasTrough( true )
+        , hasGroove( false )
+        , mouseOffset( 0 )
     {
     }
 
@@ -106,34 +107,34 @@ public:
     mutable QSize sizeHintCache;
 };
 /*!
-  Construct vertical slider in QwtSlider::Trough style
-  with a scale to the left.
+   Construct vertical slider in QwtSlider::Trough style
+   with a scale to the left.
 
-  The scale is initialized to [0.0, 100.0] and the value set to 0.0.
+   The scale is initialized to [0.0, 100.0] and the value set to 0.0.
 
-  \param parent Parent widget
+   \param parent Parent widget
 
-  \sa setOrientation(), setScalePosition(), setBackgroundStyle()
-*/
-QwtSlider::QwtSlider( QWidget *parent ):
-    QwtAbstractSlider( parent )
+   \sa setOrientation(), setScalePosition(), setBackgroundStyle()
+ */
+QwtSlider::QwtSlider( QWidget* parent )
+    : QwtAbstractSlider( parent )
 {
     initSlider( Qt::Vertical );
 }
 
 /*!
-  Construct a slider in QwtSlider::Trough style
+   Construct a slider in QwtSlider::Trough style
 
-  When orientation is Qt::Vertical the scale will be aligned to
-  the left - otherwise at the the top of the slider.
+   When orientation is Qt::Vertical the scale will be aligned to
+   the left - otherwise at the the top of the slider.
 
-  The scale is initialized to [0.0, 100.0] and the value set to 0.0.
+   The scale is initialized to [0.0, 100.0] and the value set to 0.0.
 
-  \param parent Parent widget
-  \param orientation Orientation of the slider.
-*/
-QwtSlider::QwtSlider( Qt::Orientation orientation, QWidget *parent ):
-    QwtAbstractSlider( parent )
+   \param parent Parent widget
+   \param orientation Orientation of the slider.
+ */
+QwtSlider::QwtSlider( Qt::Orientation orientation, QWidget* parent )
+    : QwtAbstractSlider( parent )
 {
     initSlider( orientation );
 }
@@ -141,7 +142,7 @@ QwtSlider::QwtSlider( Qt::Orientation orientation, QWidget *parent ):
 //! Destructor
 QwtSlider::~QwtSlider()
 {
-    delete d_data;
+    delete m_data;
 }
 
 void QwtSlider::initSlider( Qt::Orientation orientation )
@@ -153,12 +154,12 @@ void QwtSlider::initSlider( Qt::Orientation orientation )
 
     setAttribute( Qt::WA_WState_OwnSizePolicy, false );
 
-    d_data = new QwtSlider::PrivateData;
+    m_data = new QwtSlider::PrivateData;
 
-    d_data->orientation = orientation;
+    m_data->orientation = orientation;
 
     scaleDraw()->setAlignment(
-        qwtScaleDrawAlignment( orientation, d_data->scalePosition ) );
+        qwtScaleDrawAlignment( orientation, m_data->scalePosition ) );
     scaleDraw()->setLength( 100 );
 
     setScale( 0.0, 100.0 );
@@ -166,20 +167,20 @@ void QwtSlider::initSlider( Qt::Orientation orientation )
 }
 
 /*!
-  \brief Set the orientation.
-  \param orientation Allowed values are Qt::Horizontal and Qt::Vertical.
+   \brief Set the orientation.
+   \param orientation Allowed values are Qt::Horizontal and Qt::Vertical.
 
-  \sa orientation(), scalePosition()
-*/
+   \sa orientation(), scalePosition()
+ */
 void QwtSlider::setOrientation( Qt::Orientation orientation )
 {
-    if ( orientation == d_data->orientation )
+    if ( orientation == m_data->orientation )
         return;
 
-    d_data->orientation = orientation;
+    m_data->orientation = orientation;
 
     scaleDraw()->setAlignment(
-        qwtScaleDrawAlignment( orientation, d_data->scalePosition ) );
+        qwtScaleDrawAlignment( orientation, m_data->scalePosition ) );
 
     if ( !testAttribute( Qt::WA_WState_OwnSizePolicy ) )
     {
@@ -195,59 +196,59 @@ void QwtSlider::setOrientation( Qt::Orientation orientation )
 }
 
 /*!
-  \return Orientation
-  \sa setOrientation()
-*/
+   \return Orientation
+   \sa setOrientation()
+ */
 Qt::Orientation QwtSlider::orientation() const
 {
-    return d_data->orientation;
+    return m_data->orientation;
 }
 
 /*!
-  \brief Change the position of the scale
-  \param scalePosition Position of the scale.
+   \brief Change the position of the scale
+   \param scalePosition Position of the scale.
 
-  \sa ScalePosition, scalePosition()
-*/
+   \sa ScalePosition, scalePosition()
+ */
 void QwtSlider::setScalePosition( ScalePosition scalePosition )
 {
-    if ( d_data->scalePosition == scalePosition )
+    if ( m_data->scalePosition == scalePosition )
         return;
 
-    d_data->scalePosition = scalePosition;
+    m_data->scalePosition = scalePosition;
     scaleDraw()->setAlignment(
-        qwtScaleDrawAlignment( d_data->orientation, scalePosition ) );
+        qwtScaleDrawAlignment( m_data->orientation, scalePosition ) );
 
     if ( testAttribute( Qt::WA_WState_Polished ) )
         layoutSlider( true );
 }
 
 /*!
-  \return Position of the scale
-  \sa setScalePosition()
+   \return Position of the scale
+   \sa setScalePosition()
  */
 QwtSlider::ScalePosition QwtSlider::scalePosition() const
 {
-    return d_data->scalePosition;
+    return m_data->scalePosition;
 }
 
 /*!
-  \brief Change the slider's border width
+   \brief Change the slider's border width
 
-  The border width is used for drawing the slider handle and the
-  trough.
+   The border width is used for drawing the slider handle and the
+   trough.
 
-  \param width Border width
-  \sa borderWidth()
-*/
+   \param width Border width
+   \sa borderWidth()
+ */
 void QwtSlider::setBorderWidth( int width )
 {
     if ( width < 0 )
         width = 0;
 
-    if ( width != d_data->borderWidth )
+    if ( width != m_data->borderWidth )
     {
-        d_data->borderWidth = width;
+        m_data->borderWidth = width;
 
         if ( testAttribute( Qt::WA_WState_Polished ) )
             layoutSlider( true );
@@ -255,33 +256,33 @@ void QwtSlider::setBorderWidth( int width )
 }
 
 /*!
-  \return the border width.
-  \sa setBorderWidth()
-*/
+   \return the border width.
+   \sa setBorderWidth()
+ */
 int QwtSlider::borderWidth() const
 {
-    return d_data->borderWidth;
+    return m_data->borderWidth;
 }
 
 /*!
-  \brief Change the spacing between trough and scale
+   \brief Change the spacing between trough and scale
 
-  A spacing of 0 means, that the backbone of the scale is covered
-  by the trough.
+   A spacing of 0 means, that the backbone of the scale is covered
+   by the trough.
 
-  The default setting is 4 pixels.
+   The default setting is 4 pixels.
 
-  \param spacing Number of pixels
-  \sa spacing();
-*/
+   \param spacing Number of pixels
+   \sa spacing();
+ */
 void QwtSlider::setSpacing( int spacing )
 {
     if ( spacing <= 0 )
         spacing = 0;
 
-    if ( spacing != d_data->spacing  )
+    if ( spacing != m_data->spacing  )
     {
-        d_data->spacing = spacing;
+        m_data->spacing = spacing;
 
         if ( testAttribute( Qt::WA_WState_Polished ) )
             layoutSlider( true );
@@ -289,29 +290,29 @@ void QwtSlider::setSpacing( int spacing )
 }
 
 /*!
-  \return Number of pixels between slider and scale
-  \sa setSpacing()
-*/
+   \return Number of pixels between slider and scale
+   \sa setSpacing()
+ */
 int QwtSlider::spacing() const
 {
-    return d_data->spacing;
+    return m_data->spacing;
 }
 
 /*!
-  \brief Set the slider's handle size
+   \brief Set the slider's handle size
 
-  When the size is empty the slider handle will be painted with a
-  default size depending on its orientation() and backgroundStyle().
+   When the size is empty the slider handle will be painted with a
+   default size depending on its orientation() and backgroundStyle().
 
-  \param size New size
+   \param size New size
 
-  \sa handleSize()
-*/
-void QwtSlider::setHandleSize( const QSize &size )
+   \sa handleSize()
+ */
+void QwtSlider::setHandleSize( const QSize& size )
 {
-    if ( size != d_data->handleSize )
+    if ( size != m_data->handleSize )
     {
-        d_data->handleSize = size;
+        m_data->handleSize = size;
 
         if ( testAttribute( Qt::WA_WState_Polished ) )
             layoutSlider( true );
@@ -319,30 +320,30 @@ void QwtSlider::setHandleSize( const QSize &size )
 }
 
 /*!
-  \return Size of the handle.
-  \sa setHandleSize()
-*/
+   \return Size of the handle.
+   \sa setHandleSize()
+ */
 QSize QwtSlider::handleSize() const
 {
-    return d_data->handleSize;
+    return m_data->handleSize;
 }
 
 /*!
-  \brief Set a scale draw
+   \brief Set a scale draw
 
-  For changing the labels of the scales, it
-  is necessary to derive from QwtScaleDraw and
-  overload QwtScaleDraw::label().
+   For changing the labels of the scales, it
+   is necessary to derive from QwtScaleDraw and
+   overload QwtScaleDraw::label().
 
-  \param scaleDraw ScaleDraw object, that has to be created with
+   \param scaleDraw ScaleDraw object, that has to be created with
                    new and will be deleted in ~QwtSlider() or the next
                    call of setScaleDraw().
 
-  \sa scaleDraw()
-*/
-void QwtSlider::setScaleDraw( QwtScaleDraw *scaleDraw )
+   \sa scaleDraw()
+ */
+void QwtSlider::setScaleDraw( QwtScaleDraw* scaleDraw )
 {
-    const QwtScaleDraw *previousScaleDraw = this->scaleDraw();
+    const QwtScaleDraw* previousScaleDraw = this->scaleDraw();
     if ( scaleDraw == NULL || scaleDraw == previousScaleDraw )
         return;
 
@@ -356,21 +357,21 @@ void QwtSlider::setScaleDraw( QwtScaleDraw *scaleDraw )
 }
 
 /*!
-  \return the scale draw of the slider
-  \sa setScaleDraw()
-*/
-const QwtScaleDraw *QwtSlider::scaleDraw() const
+   \return the scale draw of the slider
+   \sa setScaleDraw()
+ */
+const QwtScaleDraw* QwtSlider::scaleDraw() const
 {
-    return static_cast<const QwtScaleDraw *>( abstractScaleDraw() );
+    return static_cast< const QwtScaleDraw* >( abstractScaleDraw() );
 }
 
 /*!
-  \return the scale draw of the slider
-  \sa setScaleDraw()
-*/
-QwtScaleDraw *QwtSlider::scaleDraw()
+   \return the scale draw of the slider
+   \sa setScaleDraw()
+ */
+QwtScaleDraw* QwtSlider::scaleDraw()
 {
-    return static_cast<QwtScaleDraw *>( abstractScaleDraw() );
+    return static_cast< QwtScaleDraw* >( abstractScaleDraw() );
 }
 
 //! Notify changed scale
@@ -383,26 +384,26 @@ void QwtSlider::scaleChange()
 }
 
 /*!
-  \brief Specify the update interval for automatic scrolling
+   \brief Specify the update interval for automatic scrolling
 
-  The minimal accepted value is 50 ms.
+   The minimal accepted value is 50 ms.
 
-  \param interval Update interval in milliseconds
+   \param interval Update interval in milliseconds
 
-  \sa setUpdateInterval()
-*/
+   \sa setUpdateInterval()
+ */
 void QwtSlider::setUpdateInterval( int interval )
 {
-    d_data->updateInterval = qMax( interval, 50 );
+    m_data->updateInterval = qMax( interval, 50 );
 }
 
 /*!
-  \return Update interval in milliseconds for automatic scrolling
-  \sa setUpdateInterval()
+   \return Update interval in milliseconds for automatic scrolling
+   \sa setUpdateInterval()
  */
 int QwtSlider::updateInterval() const
 {
-    return d_data->updateInterval;
+    return m_data->updateInterval;
 }
 
 /*!
@@ -410,26 +411,26 @@ int QwtSlider::updateInterval() const
 
    \param painter Painter
    \param sliderRect Bounding rectangle of the slider
-*/
+ */
 void QwtSlider::drawSlider(
-    QPainter *painter, const QRect &sliderRect ) const
+    QPainter* painter, const QRect& sliderRect ) const
 {
     QRect innerRect( sliderRect );
 
-    if ( d_data->hasTrough )
+    if ( m_data->hasTrough )
     {
-        const int bw = d_data->borderWidth;
+        const int bw = m_data->borderWidth;
         innerRect = sliderRect.adjusted( bw, bw, -bw, -bw );
 
         painter->fillRect( innerRect, palette().brush( QPalette::Mid ) );
         qDrawShadePanel( painter, sliderRect, palette(), true, bw, NULL );
     }
 
-    const QSize handleSize = qwtHandleSize( d_data->handleSize,
-        d_data->orientation, d_data->hasTrough );
-
-    if ( d_data->hasGroove )
+    if ( m_data->hasGroove )
     {
+        const QSize handleSize = qwtHandleSize( m_data->handleSize,
+            m_data->orientation, m_data->hasTrough );
+
         const int slotExtent = 4;
         const int slotMargin = 4;
 
@@ -455,7 +456,7 @@ void QwtSlider::drawSlider(
         slotRect.moveCenter( innerRect.center() );
 
         QBrush brush = palette().brush( QPalette::Dark );
-        qDrawShadePanel( painter, slotRect, palette(), true, 1 , &brush );
+        qDrawShadePanel( painter, slotRect, palette(), true, 1, &brush );
     }
 
     if ( isValid() )
@@ -463,16 +464,16 @@ void QwtSlider::drawSlider(
 }
 
 /*!
-  Draw the thumb at a position
+   Draw the thumb at a position
 
-  \param painter Painter
-  \param handleRect Bounding rectangle of the handle
-  \param pos Position of the handle marker in widget coordinates
-*/
-void QwtSlider::drawHandle( QPainter *painter,
-    const QRect &handleRect, int pos ) const
+   \param painter Painter
+   \param handleRect Bounding rectangle of the handle
+   \param pos Position of the handle marker in widget coordinates
+ */
+void QwtSlider::drawHandle( QPainter* painter,
+    const QRect& handleRect, int pos ) const
 {
-    const int bw = d_data->borderWidth;
+    const int bw = m_data->borderWidth;
 
     qDrawShadePanel( painter,
         handleRect, palette(), false, bw,
@@ -492,21 +493,21 @@ void QwtSlider::drawHandle( QPainter *painter,
 }
 
 /*!
-  \brief Determine what to do when the user presses a mouse button.
+   \brief Determine what to do when the user presses a mouse button.
 
-  \param pos Mouse position
+   \param pos Mouse position
 
-  \retval True, when handleRect() contains pos
-  \sa scrolledTo()
-*/
-bool QwtSlider::isScrollPosition( const QPoint &pos ) const
+   \retval True, when handleRect() contains pos
+   \sa scrolledTo()
+ */
+bool QwtSlider::isScrollPosition( const QPoint& pos ) const
 {
     if ( handleRect().contains( pos ) )
     {
         const double v = ( orientation() == Qt::Horizontal )
             ? pos.x() : pos.y();
 
-        d_data->mouseOffset = v - transform( value() );
+        m_data->mouseOffset = v - transform( value() );
         return true;
     }
 
@@ -514,20 +515,20 @@ bool QwtSlider::isScrollPosition( const QPoint &pos ) const
 }
 
 /*!
-  \brief Determine the value for a new position of the
+   \brief Determine the value for a new position of the
          slider handle.
 
-  \param pos Mouse position
+   \param pos Mouse position
 
-  \return Value for the mouse position
-  \sa isScrollPosition()
-*/
-double QwtSlider::scrolledTo( const QPoint &pos ) const
+   \return Value for the mouse position
+   \sa isScrollPosition()
+ */
+double QwtSlider::scrolledTo( const QPoint& pos ) const
 {
     int p = ( orientation() == Qt::Horizontal )
         ? pos.x() : pos.y();
 
-    p -= d_data->mouseOffset;
+    p -= m_data->mouseOffset;
 
     int min = transform( lowerBound() );
     int max = transform( upperBound() );
@@ -542,8 +543,8 @@ double QwtSlider::scrolledTo( const QPoint &pos ) const
 /*!
    Mouse press event handler
    \param event Mouse event
-*/
-void QwtSlider::mousePressEvent( QMouseEvent *event )
+ */
+void QwtSlider::mousePressEvent( QMouseEvent* event )
 {
     if ( isReadOnly() )
     {
@@ -553,43 +554,43 @@ void QwtSlider::mousePressEvent( QMouseEvent *event )
 
     const QPoint pos = event->pos();
 
-    if ( isValid() && d_data->sliderRect.contains( pos ) )
+    if ( isValid() && m_data->sliderRect.contains( pos ) )
     {
         if ( !handleRect().contains( pos ) )
         {
             const int markerPos = transform( value() );
 
-            d_data->stepsIncrement = pageSteps();
+            m_data->stepsIncrement = pageSteps();
 
-            if ( d_data->orientation == Qt::Horizontal )
+            if ( m_data->orientation == Qt::Horizontal )
             {
                 if ( pos.x() < markerPos )
-                    d_data->stepsIncrement = -d_data->stepsIncrement;
+                    m_data->stepsIncrement = -m_data->stepsIncrement;
             }
             else
             {
                 if ( pos.y() < markerPos )
-                    d_data->stepsIncrement = -d_data->stepsIncrement;
+                    m_data->stepsIncrement = -m_data->stepsIncrement;
             }
 
             if ( isInverted() )
-                d_data->stepsIncrement = -d_data->stepsIncrement;
+                m_data->stepsIncrement = -m_data->stepsIncrement;
 
             const double v = value();
-            incrementValue( d_data->stepsIncrement );
+            incrementValue( m_data->stepsIncrement );
 
             if ( v != value() )
             {
                 if ( isTracking() )
                     Q_EMIT valueChanged( value() );
                 else
-                    d_data->pendingValueChange = true;
+                    m_data->pendingValueChange = true;
 
                 Q_EMIT sliderMoved( value() );
             }
 
-            d_data->timerTick = false;
-            d_data->repeatTimerId = startTimer( qMax( 250, 2 * updateInterval() ) );
+            m_data->timerTick = false;
+            m_data->repeatTimerId = startTimer( qMax( 250, 2 * updateInterval() ) );
 
             return;
         }
@@ -601,20 +602,20 @@ void QwtSlider::mousePressEvent( QMouseEvent *event )
 /*!
    Mouse release event handler
    \param event Mouse event
-*/
-void QwtSlider::mouseReleaseEvent( QMouseEvent *event )
+ */
+void QwtSlider::mouseReleaseEvent( QMouseEvent* event )
 {
-    if ( d_data->repeatTimerId > 0 )
+    if ( m_data->repeatTimerId > 0 )
     {
-        killTimer( d_data->repeatTimerId );
-        d_data->repeatTimerId = 0;
-        d_data->timerTick = false;
-        d_data->stepsIncrement = 0;
+        killTimer( m_data->repeatTimerId );
+        m_data->repeatTimerId = 0;
+        m_data->timerTick = false;
+        m_data->stepsIncrement = 0;
     }
 
-    if ( d_data->pendingValueChange )
+    if ( m_data->pendingValueChange )
     {
-        d_data->pendingValueChange = false;
+        m_data->pendingValueChange = false;
         Q_EMIT valueChanged( value() );
     }
 
@@ -628,10 +629,10 @@ void QwtSlider::mouseReleaseEvent( QMouseEvent *event )
    inside the sliderRect().
 
    \param event Mouse event
-*/
-void QwtSlider::timerEvent( QTimerEvent *event )
+ */
+void QwtSlider::timerEvent( QTimerEvent* event )
 {
-    if ( event->timerId() != d_data->repeatTimerId )
+    if ( event->timerId() != m_data->repeatTimerId )
     {
         QwtAbstractSlider::timerEvent( event );
         return;
@@ -639,75 +640,88 @@ void QwtSlider::timerEvent( QTimerEvent *event )
 
     if ( !isValid() )
     {
-        killTimer( d_data->repeatTimerId );
-        d_data->repeatTimerId = 0;
+        killTimer( m_data->repeatTimerId );
+        m_data->repeatTimerId = 0;
         return;
     }
 
     const double v = value();
-    incrementValue( d_data->stepsIncrement );
+    incrementValue( m_data->stepsIncrement );
 
     if ( v != value() )
     {
         if ( isTracking() )
             Q_EMIT valueChanged( value() );
         else
-            d_data->pendingValueChange = true;
+            m_data->pendingValueChange = true;
 
         Q_EMIT sliderMoved( value() );
     }
 
-    if ( !d_data->timerTick )
+    if ( !m_data->timerTick )
     {
         // restart the timer with a shorter interval
-        killTimer( d_data->repeatTimerId );
-        d_data->repeatTimerId = startTimer( updateInterval() );
+        killTimer( m_data->repeatTimerId );
+        m_data->repeatTimerId = startTimer( updateInterval() );
 
-        d_data->timerTick = true;
+        m_data->timerTick = true;
     }
 }
 
 /*!
    Qt paint event handler
    \param event Paint event
-*/
-void QwtSlider::paintEvent( QPaintEvent *event )
+ */
+void QwtSlider::paintEvent( QPaintEvent* event )
 {
     QPainter painter( this );
     painter.setClipRegion( event->region() );
 
     QStyleOption opt;
-    opt.init(this);
+    opt.initFrom(this);
     style()->drawPrimitive(QStyle::PE_Widget, &opt, &painter, this);
 
-    if ( d_data->scalePosition != QwtSlider::NoScale )
+    if ( m_data->scalePosition != QwtSlider::NoScale )
     {
-        if ( !d_data->sliderRect.contains( event->rect() ) )
+        if ( !m_data->sliderRect.contains( event->rect() ) )
             scaleDraw()->draw( &painter, palette() );
     }
 
-    drawSlider( &painter, d_data->sliderRect );
+    drawSlider( &painter, m_data->sliderRect );
 
     if ( hasFocus() )
-        QwtPainter::drawFocusRect( &painter, this, d_data->sliderRect );
+        QwtPainter::drawFocusRect( &painter, this, m_data->sliderRect );
 }
 
 /*!
    Qt resize event handler
    \param event Resize event
-*/
-void QwtSlider::resizeEvent( QResizeEvent *event )
+ */
+void QwtSlider::resizeEvent( QResizeEvent* event )
 {
-    Q_UNUSED( event );
-
     layoutSlider( false );
+    QwtAbstractSlider::resizeEvent( event );
+}
+
+/*!
+   Qt event handler
+   \param event Event
+
+   \return true, if event was recognized and processed
+ */
+bool QwtSlider::event( QEvent* event )
+{
+    if ( event->type() == QEvent::PolishRequest )
+        layoutSlider( false );
+
+    return QwtAbstractSlider::event( event );
 }
 
 /*!
    Handles QEvent::StyleChange and QEvent::FontChange events
    \param event Change event
-*/
-void QwtSlider::changeEvent( QEvent *event )
+ */
+void QwtSlider::changeEvent( QEvent* event )
 {
     if ( event->type() == QEvent::StyleChange ||
         event->type() == QEvent::FontChange )
@@ -720,20 +734,20 @@ void QwtSlider::changeEvent( QEvent *event )
 }
 
 /*!
-  Recalculate the slider's geometry and layout based on
-  the current geometry and fonts.
+   Recalculate the slider's geometry and layout based on
+   the current geometry and fonts.
 
-  \param update_geometry  notify the layout system and call update
+   \param update_geometry  notify the layout system and call update
          to redraw the scale
-*/
+ */
 void QwtSlider::layoutSlider( bool update_geometry )
 {
     int bw = 0;
-    if ( d_data->hasTrough )
-        bw = d_data->borderWidth;
+    if ( m_data->hasTrough )
+        bw = m_data->borderWidth;
 
-    const QSize handleSize = qwtHandleSize( d_data->handleSize,
-        d_data->orientation, d_data->hasTrough );
+    const QSize handleSize = qwtHandleSize( m_data->handleSize,
+        m_data->orientation, m_data->hasTrough );
 
     QRect sliderRect = contentsRect();
 
@@ -751,7 +765,7 @@ void QwtSlider::layoutSlider( bool update_geometry )
      */
 
     int scaleMargin = 0;
-    if ( d_data->scalePosition != QwtSlider::NoScale )
+    if ( m_data->scalePosition != QwtSlider::NoScale )
     {
         int d1, d2;
         scaleDraw()->getBorderDistHint( font(), d1, d2 );
@@ -761,7 +775,7 @@ void QwtSlider::layoutSlider( bool update_geometry )
 
     int scaleX, scaleY, scaleLength;
 
-    if ( d_data->orientation == Qt::Horizontal )
+    if ( m_data->orientation == Qt::Horizontal )
     {
         const int handleMargin = handleSize.width() / 2 - 1;
         if ( scaleMargin > handleMargin )
@@ -790,64 +804,64 @@ void QwtSlider::layoutSlider( bool update_geometry )
 
     // now align slider and scale according to the ScalePosition
 
-    if ( d_data->orientation == Qt::Horizontal )
+    if ( m_data->orientation == Qt::Horizontal )
     {
         const int h = handleSize.height() + 2 * bw;
 
-        if ( d_data->scalePosition == QwtSlider::TrailingScale )
+        if ( m_data->scalePosition == QwtSlider::TrailingScale )
         {
             sliderRect.setTop( sliderRect.bottom() + 1 - h );
-            scaleY = sliderRect.top() - d_data->spacing;
+            scaleY = sliderRect.top() - m_data->spacing;
         }
         else
         {
             sliderRect.setHeight( h );
-            scaleY = sliderRect.bottom() + 1 + d_data->spacing;
+            scaleY = sliderRect.bottom() + 1 + m_data->spacing;
         }
     }
     else // Qt::Vertical
     {
         const int w = handleSize.width() + 2 * bw;
 
-        if ( d_data->scalePosition == QwtSlider::LeadingScale )
+        if ( m_data->scalePosition == QwtSlider::LeadingScale )
         {
             sliderRect.setWidth( w );
-            scaleX = sliderRect.right() + 1 + d_data->spacing;
+            scaleX = sliderRect.right() + 1 + m_data->spacing;
         }
         else
         {
             sliderRect.setLeft( sliderRect.right() + 1 - w );
-            scaleX = sliderRect.left() - d_data->spacing;
+            scaleX = sliderRect.left() - m_data->spacing;
         }
     }
 
-    d_data->sliderRect = sliderRect;
+    m_data->sliderRect = sliderRect;
 
     scaleDraw()->move( scaleX, scaleY );
     scaleDraw()->setLength( scaleLength );
 
     if ( update_geometry )
     {
-        d_data->sizeHintCache = QSize(); // invalidate
+        m_data->sizeHintCache = QSize(); // invalidate
         updateGeometry();
         update();
     }
 }
 
 /*!
-  En/Disable the trough
+   En/Disable the trough
 
-  The slider can be cutomized by showing a trough for the
-  handle.
+   The slider can be customized by showing a trough for the
+   handle.
 
-  \param on When true, the groove is visible
-  \sa hasTrough(), setGroove()
+   \param on When true, the groove is visible
+   \sa hasTrough(), setGroove()
  */
 void QwtSlider::setTrough( bool on )
 {
-    if ( d_data->hasTrough != on )
+    if ( m_data->hasTrough != on )
     {
-        d_data->hasTrough = on;
+        m_data->hasTrough = on;
 
         if ( testAttribute( Qt::WA_WState_Polished ) )
             layoutSlider( true );
@@ -855,28 +869,28 @@ void QwtSlider::setTrough( bool on )
 }
 
 /*!
-  \return True, when the trough is visisble
-  \sa setTrough(), hasGroove()
+   \return True, when the trough is visible
+   \sa setTrough(), hasGroove()
  */
 bool QwtSlider::hasTrough() const
 {
-    return d_data->hasTrough;
+    return m_data->hasTrough;
 }
 
 /*!
-  En/Disable the groove
+   En/Disable the groove
 
-  The slider can be cutomized by showing a groove for the
-  handle.
+   The slider can be customized by showing a groove for the
+   handle.
 
-  \param on When true, the groove is visible
-  \sa hasGroove(), setThrough()
+   \param on When true, the groove is visible
+   \sa hasGroove(), setThrough()
  */
 void QwtSlider::setGroove( bool on )
 {
-    if ( d_data->hasGroove != on )
+    if ( m_data->hasGroove != on )
     {
-        d_data->hasGroove = on;
+        m_data->hasGroove = on;
 
         if ( testAttribute( Qt::WA_WState_Polished ) )
             layoutSlider( true );
@@ -884,43 +898,43 @@ void QwtSlider::setGroove( bool on )
 }
 
 /*!
-  \return True, when the groove is visisble
-  \sa setGroove(), hasTrough()
+   \return True, when the groove is visible
+   \sa setGroove(), hasTrough()
  */
 bool QwtSlider::hasGroove() const
 {
-    return d_data->hasGroove;
+    return m_data->hasGroove;
 }
 
 /*!
-  \return minimumSizeHint()
-*/
+   \return minimumSizeHint()
+ */
 QSize QwtSlider::sizeHint() const
 {
     const QSize hint = minimumSizeHint();
-    return hint.expandedTo( QApplication::globalStrut() );
+    return qwtExpandedToGlobalStrut( hint );
 }
 
 /*!
-  \return Minimum size hint
-  \sa sizeHint()
-*/
+   \return Minimum size hint
+   \sa sizeHint()
+ */
 QSize QwtSlider::minimumSizeHint() const
 {
-    if ( !d_data->sizeHintCache.isEmpty() )
-        return d_data->sizeHintCache;
+    if ( !m_data->sizeHintCache.isEmpty() )
+        return m_data->sizeHintCache;
 
-    const QSize handleSize = qwtHandleSize( d_data->handleSize,
-        d_data->orientation, d_data->hasTrough );
+    const QSize handleSize = qwtHandleSize( m_data->handleSize,
+        m_data->orientation, m_data->hasTrough );
 
     int bw = 0;
-    if ( d_data->hasTrough )
-        bw = d_data->borderWidth;
+    if ( m_data->hasTrough )
+        bw = m_data->borderWidth;
 
     int sliderLength = 0;
     int scaleExtent = 0;
 
-    if ( d_data->scalePosition != QwtSlider::NoScale )
+    if ( m_data->scalePosition != QwtSlider::NoScale )
     {
         int d1, d2;
         scaleDraw()->getBorderDistHint( font(), d1, d2 );
@@ -928,7 +942,7 @@ QSize QwtSlider::minimumSizeHint() const
         const int scaleBorderDist = 2 * ( qMax( d1, d2 ) - bw );
 
         int handleBorderDist;
-        if ( d_data->orientation == Qt::Horizontal )
+        if ( m_data->orientation == Qt::Horizontal )
             handleBorderDist = handleSize.width();
         else
             handleBorderDist = handleSize.height();
@@ -940,8 +954,8 @@ QSize QwtSlider::minimumSizeHint() const
             sliderLength += handleBorderDist - scaleBorderDist;
         }
 
-        scaleExtent += d_data->spacing;
-        scaleExtent += qCeil( scaleDraw()->extent( font() ) );
+        scaleExtent += m_data->spacing;
+        scaleExtent += qwtCeil( scaleDraw()->extent( font() ) );
     }
 
     sliderLength = qMax( sliderLength, 84 ); // from QSlider
@@ -949,7 +963,7 @@ QSize QwtSlider::minimumSizeHint() const
     int w = 0;
     int h = 0;
 
-    if ( d_data->orientation == Qt::Horizontal )
+    if ( m_data->orientation == Qt::Horizontal )
     {
         w = sliderLength;
         h = handleSize.height() + 2 * bw + scaleExtent;
@@ -961,14 +975,13 @@ QSize QwtSlider::minimumSizeHint() const
     }
 
     // finally add margins
-    int left, right, top, bottom;
-    getContentsMargins( &left, &top, &right, &bottom );
+    const QMargins m = contentsMargins();
 
-    w += left + right;
-    h += top + bottom;
+    w += m.left() + m.right();
+    h += m.top() + m.bottom();
 
-    d_data->sizeHintCache = QSize( w, h );
-    return d_data->sizeHintCache;
+    m_data->sizeHintCache = QSize( w, h );
+    return m_data->sizeHintCache;
 }
 
 /*!
@@ -981,24 +994,26 @@ QRect QwtSlider::handleRect() const
 
     const int markerPos = transform( value() );
 
-    QPoint center = d_data->sliderRect.center();
-    if ( d_data->orientation == Qt::Horizontal )
+    QPoint center = m_data->sliderRect.center();
+    if ( m_data->orientation == Qt::Horizontal )
         center.setX( markerPos );
     else
         center.setY( markerPos );
 
     QRect rect;
-    rect.setSize( qwtHandleSize( d_data->handleSize,
-        d_data->orientation, d_data->hasTrough ) );
+    rect.setSize( qwtHandleSize( m_data->handleSize,
+        m_data->orientation, m_data->hasTrough ) );
     rect.moveCenter( center );
 
     return rect;
 }
 
 /*!
- \return Bounding rectangle of the slider - without the scale
+   \return Bounding rectangle of the slider - without the scale
  */
 QRect QwtSlider::sliderRect() const
 {
-    return d_data->sliderRect;
+    return m_data->sliderRect;
 }
+
+#include "moc_qwt_slider.cpp"
